<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/admin
 * @author     Easy Soft <nashirbabu@gmail.com>
 */

 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/easy-map-admin-display.php';

 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-easy-map-location.php';
 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/easy-map-location-display.php';

 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-easy-map-draw.php';
 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/easy-map-draw-display.php';

class Easy_Map_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.2.6
	 * @access   protected
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	protected $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.2.6
	 * @access   protected
	 * @var      string    $version    The current version of this plugin.
	 */
	protected $version;


	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      object    $admin_display    Admin Display class object.
	 */

	protected $admin_display;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.3.4
	 * @access   private
	 * @var      string    $map_setting    The current version of this plugin.
	 */
	protected $map_setting;

	 /**
     * Holds the data
     *
     * @var array
     */
    public $map = [];

	/**
     * Holds the errors
     *
     * @var array
     */
    public $errors = [];

	const SHORTCODE_PREPIX = 'easy_map_id_';


	public static  $allowed_html = array(
		'a' => array(
			'href' => array(),
			'title' => array()
		),
		'br' => array(),
		'em' => array(),
		'strong' => array(),
		'p' => array(),
		'ul' => array(),
		'ol' => array(),
		'li' => array(),
		'blockquote' => array(),
		'cite' => array(),
		'h1' => array(),
		'h2' => array(),
		'h3' => array(),
		'h4' => array(),
		'h5' => array(),
		'h6' => array(),
		'img' => array(
			'src' => array(),
			'alt' => array(),
			'width' => array(),
			'height' => array(),
		),
	);

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since      1.2.6
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		add_shortcode('easy-map-br', [$this, 'easy_map_line_break']);

		$this->map_setting = Easy_Map_Settings::getSetting();

		add_action( 'admin_post_easy-map-delete', [ $this, 'delete_map' ] );
		add_action( 'admin_post_easy-map-location-delete', [ $this, 'delete_map_location' ] );
		add_action( 'admin_post_easy-map-draw-delete', [ $this, 'delete_map_draw' ] );
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.2.6
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Map_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Map_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/easy-map-admin.css', array(), $this->version, 'all');

		wp_register_style('easy_map_css', plugins_url('../assets/leaflet/leaflet.css', __FILE__));
		wp_enqueue_style('easy_map_css');

		wp_register_style('easy_map_draw_css', plugins_url('../assets/leaflet/leaflet.draw.css', __FILE__));
		wp_enqueue_style('easy_map_draw_css');

		wp_register_style('easy_map_custom_css', plugins_url('../assets/css/easy_map.css', __FILE__), null, null, false);
		wp_enqueue_style('easy_map_custom_css');

		//if (isset($this->map_setting['fullScreen']) && $this->map_setting['fullScreen'] == 1 ) { 
			wp_register_style('easy_map_fullscreen', plugins_url('../assets/leaflet/FullScreen.css', __FILE__));
			wp_enqueue_style('easy_map_fullscreen');
		//}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.2.6
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Map_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Map_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/easy-map-admin.js', array('jquery'), $this->version, true);

		wp_localize_script($this->plugin_name, 'map_ajax_info', array(
			'url' => admin_url('admin-ajax.php'),
			'nonce' => wp_create_nonce('easy-map-ajax-nonce')
		));

		wp_register_script('easy_map_js', plugins_url('../assets/leaflet/leaflet.js', __FILE__), null, null, true);
		wp_enqueue_script('easy_map_js');

		wp_register_script('easy_map_draw_js', plugins_url('../assets/leaflet/Leaflet.draw.js', __FILE__), null, null, true);
		wp_enqueue_script('easy_map_draw_js');


		wp_register_script('easy_map_bing', plugins_url('../assets/leaflet/leaflet-bing-layer.js', __FILE__), null, null, true);
		wp_enqueue_script('easy_map_bing');

		if (isset($this->map_setting['googleMapKey']) && $this->map_setting['googleMapKey'] != '') {
			wp_register_script('easy_map_key', 'https://maps.googleapis.com/maps/api/js?key=' . $this->map_setting['googleMapKey'], null, null, true);
			wp_enqueue_script('easy_map_key');

			wp_register_script('easy_map_google', plugins_url('../assets/leaflet/GoogleMutant.js', __FILE__), null, null, true);
			wp_enqueue_script('easy_map_google');
		}

		//if (isset($this->map_setting['fullScreen']) && $this->map_setting['fullScreen'] == 1 ) { 
			wp_register_script('easy_map_fullscreen', plugins_url('../assets/leaflet/FullScreen.js', __FILE__), null, null, true);
			wp_enqueue_script('easy_map_fullscreen');
		//}

		wp_register_script('easy_map_custom_js', plugins_url('../assets/js/easy_map.js', __FILE__), null, null, true);
		wp_enqueue_script('easy_map_custom_js');

		wp_register_script('easy_map_public_js', plugins_url('../assets/js/easy_map_public.js', __FILE__), null, null, true);
		wp_enqueue_script('easy_map_public_js');

		wp_register_script('easy_map_drawing_js', plugins_url('../assets/js/easy_map_draw.js', __FILE__), null, null, true);
		wp_enqueue_script('easy_map_drawing_js');


		
	}

	/**
	 * Register the Plugin's Admin Pages for the admin area.
	 *
	 * @since    1.2.6
	 */
	public function load_admin_pages()
	{

		$logo = 'dashicons-location-alt';

		$capability = "edit_posts";

		
		add_menu_page(__('Easy Map', 'easy-map'), __('Easy Map', 'easy-map'),  $capability, 'easy-map', array($this, 'easy_map_manage'), $logo);
		add_submenu_page('easy-map', __('Manage Map', 'easy-map'), __('Manage Map', 'easy-map'),  $capability, 'easy-map', array($this, 'easy_map_manage') );
		add_submenu_page('easy-map', __('Add Map', 'easy-map'), __('Add Map', 'easy-map'),  $capability, 'easy-map-add', array($this, 'easy_map_add') );

		add_submenu_page('easy-map', __('Manage Location', 'easy-map'), __('Manage Location', 'easy-map'),  $capability, 'easy-map-location', array($this, 'easy_map_location') );
		add_submenu_page('easy-map', __('Add Location', 'easy-map'), __('Add Location', 'easy-map'),  $capability, 'easy-map-add-location', array($this, 'easy_map_add_location') );

		add_submenu_page('easy-map', __('Manage Drawing', 'easy-map'), __('Manage Drawing', 'easy-map'),  $capability, 'easy-map-draw', array($this, 'easy_map_draw') );
		add_submenu_page('easy-map', __('Add Drawing', 'easy-map'), __('Add Drawing', 'easy-map'),  $capability, 'easy-map-add-draw', array($this, 'easy_map_add_draw') );
		
		add_submenu_page('easy-map', __('Settings', 'easy-map'), __('Settings', 'easy-map'),  $capability, 'easy-map-settings', array($this, 'easy_map_settings'));
		add_submenu_page('easy-map', __('Shortcode Sample', 'easy-map'), __('Shortcode Sample', 'easy-map'),  $capability, 'easy-map-shortcode', array($this, 'easy_map_shortcode'));
	
		$this->admin_display = new Easy_Map_Admin_Display();
	}

	public function easy_map_location(){
		$location = new Easy_Map_Location( $this->plugin_name, $this->version );
		add_shortcode('easy-map-edit-location', [$location, 'easy_map_edit_location_render']);
		$location->easy_map_location();
	}

	public function easy_map_add_location(){
		$location = new Easy_Map_Location( $this->plugin_name, $this->version );
		$location->easy_map_add_location();
	}

	public function easy_map_draw(){
		$draw = new Easy_Map_Draw( $this->plugin_name, $this->version );
		$draw->easy_map_draw();
	}

	public function easy_map_add_draw(){
		$draw = new Easy_Map_Draw( $this->plugin_name, $this->version );
		add_shortcode('easy-map-draw', [$draw, 'easy_map_draw_render']);
		$draw->easy_map_add_draw();
	}

	public function delete_map(){

		if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'], 'easy-map-delete' ) ) {
			wp_die( 'Something is wrong!' );
        }

        if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( 'Something is wrong!' );
        }

        $value = isset( $_REQUEST['value'] ) ? intval( $_REQUEST['value'] ) : 0;

		$option_name=Easy_Map_Admin::SHORTCODE_PREPIX.$value;

        if ( delete_option( $option_name ) ) {
            $redirected_to = admin_url( 'admin.php?page=easy-map&map-deleted=true' );
        } else {
            $redirected_to = admin_url( 'admin.php?page=easy-map&map-deleted=false' );
        }

        wp_redirect( $redirected_to );
        exit;
	}

	public function delete_map_location(){

		if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'], 'easy-map-location-delete' ) ) {
			wp_die( 'Something is wrong!' );
        }

        if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( 'Something is wrong!' );
        }

        $id = isset( $_REQUEST['id'] ) ? intval( $_REQUEST['id'] ) : 0;

		$is_deleted = Easy_Map_Location_Display::delete_location($id);

        if ( $is_deleted )  {
            $redirected_to = admin_url( 'admin.php?page=easy-map-location&location-deleted=true' );
        } else {
            $redirected_to = admin_url( 'admin.php?page=easy-map-location&location-deleted=false' );
        }

        wp_redirect( $redirected_to );
        exit;
	
	}

	public function delete_map_draw(){

		if ( ! wp_verify_nonce( $_REQUEST['_wpnonce'], 'easy-map-draw-delete' ) ) {
			wp_die( 'Something is wrong!' );
        }

        if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( 'Something is wrong!' );
        }

        $id = isset( $_REQUEST['id'] ) ? intval( $_REQUEST['id'] ) : 0;

		$is_deleted = Easy_Map_Draw_Display::delete_drawing($id);

        if ( $is_deleted )  {
            $redirected_to = admin_url( 'admin.php?page=easy-map-draw&draw-deleted=true' );
        } else {
            $redirected_to = admin_url( 'admin.php?page=easy-map-draw&draw-deleted=false' );
        }

        wp_redirect( $redirected_to );
        exit;
	
	}
	

	public function easy_map_edit($value){
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Edit Easy Map', 'easy-map' ); ?></h1>
			<?php
			$option_name=Easy_Map_Admin::SHORTCODE_PREPIX.$value;
			$easy_map_setting=unserialize(get_option($option_name));
			
			$this->map_setting = $easy_map_setting;
			echo do_shortcode("[easy-map-edit]");

			
			if(!empty($_POST)){
				$this->form_handler();
			}
			?>
			
			<form action="" method="post">
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php esc_html_e('Title', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text" type="text" value="<?php echo esc_attr($easy_map_setting['title']); ?>" name="title" id="title">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="lat"><?php esc_html_e('Latitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error('lat') ? ' easy-map-form-invalid' : ''); ?>"
									value="<?php echo esc_attr($easy_map_setting['lat']); ?>" name="lat" id="lat">
								<?php if ($this->has_error('lat')) { ?>
									<p class="description error"><?php echo esc_attr($this->get_error('lat')); ?></p>
								<?php } ?>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="lon"><?php echo esc_attr('Longitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error('lon') ? ' easy-map-form-invalid' : ''); ?>"
									value="<?php echo esc_attr($easy_map_setting['lon']); ?>" name="lon" id="lon">
								<?php if ($this->has_error('lat')) { ?>
									<p class="description error"><?php echo esc_attr($this->get_error('lat')); ?></p>
								<?php } ?>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="zoom"><?php esc_html_e('Zoom', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error('zoom') ? ' easy-map-form-invalid' : ''); ?>"
									type="number" value="<?php echo esc_attr($easy_map_setting['zoom']); ?>" name="zoom" id="zoom">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Popup', 'easy-map'); ?></label>
							</th>
							<td>
								<?php
								// Use wp_editor function to create a rich text editor
								$content = $easy_map_setting['popup'];
								$editor_id = 'popup';
								$settings = array(
									'textarea_name' => 'popup',
									'media_buttons' => true,
									'textarea_rows' => 10,
									'teeny'         => false,
									'tinymce'       => true,
								);

								wp_editor( $content, $editor_id, $settings );
								?>
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['openPopup'])) {
								$openPopup = $easy_map_setting['openPopup'];
							} else {
								$openPopup = true;
							}
							?>
							<th scope="row">
								<label for="openPopup"><?php esc_html_e('Default Open Popup', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($openPopup)
									echo esc_attr('checked'); ?> ; name="openPopup" id="openPopup">
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['marker']) && $easy_map_setting['marker'] == 1) {
								$marker = true;
							} else {
								$marker = false;
							}
							?>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Default Marker', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($marker)
									echo esc_attr('checked'); ?> ; name="marker" id="marker">
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['zoomControl']) && $easy_map_setting['zoomControl'] == 1) {
								$zoom_control = true;
							} else {
								$zoom_control = false;
							}
							?>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Zoom Control', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($zoom_control)
									echo esc_attr('checked'); ?> ; name="zoomControl"
									id="zoomControl">
							</td>
						</tr>
						<tr>
							<?php
							$zoom_control_position = isset($easy_map_setting['zoomControlPosition']) ? sanitize_text_field($easy_map_setting['zoomControlPosition']) : 'topleft';
							?>
							<th scope="row">
								<label for="zoomControlPosition"><?php esc_html_e('Zoom Control Position', 'easy-map'); ?></label>
							</th>
							<td>
								<select name="zoomControlPosition" id="zoomControlPosition">
									<option <?php if ($zoom_control_position == 'topleft')
										echo esc_attr('selected'); ?> value="topleft">topleft</option>
									<option <?php if ($zoom_control_position == 'topright')
										echo esc_attr('selected'); ?> value="topright">topright</option>
									<option <?php if ($zoom_control_position == 'bottomleft')
										echo esc_attr('selected'); ?> value="bottomleft">bottomleft
									</option>
									<option <?php if ($zoom_control_position == 'bottomright')
										echo esc_attr('selected'); ?> value="bottomright">bottomright
									</option>
								</select>
						
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['scrollWheelZoom']) && $easy_map_setting['scrollWheelZoom'] == 1) {
								$scroll_wheel_zoom = true;
							} else {
								$scroll_wheel_zoom = false;
							}
							?>
							<th scope="row">
								<label for="scrollWheelZoom"><?php esc_html_e('Scroll Wheel Zoom', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($scroll_wheel_zoom)
									echo esc_attr('checked'); ?> ; name="scrollWheelZoom"
									id="scrollWheelZoom">
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['fullScreen']) && $easy_map_setting['fullScreen'] == 1) {
								$full_screen = true;
							} else {
								$full_screen = false;
							}
							?>
							<th scope="row">
								<label for="fullScreen"><?php esc_html_e('Full Screen', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($full_screen)
									echo esc_attr('checked'); ?> ; name="fullScreen" id="fullScreen">
							</td>
						</tr>
					
					</tbody>
				</table>
				<input type="hidden" name="option_name" value="<?php echo esc_attr($option_name); ?>" />
				<?php wp_nonce_field( 'easy-map-add' ); ?>
				<?php submit_button( __( 'Update', 'easy-map' ), 'primary', 'submit_map' ); ?>
			</form>
		</div>
		<?php
	}

	public function easy_map_manage(){
	
		if (current_user_can('manage_options')) {
			$action = isset( $_GET['action'] ) ? $_GET['action'] : '';
			$value  = isset( $_GET['value'] ) ? intval( $_GET['value'] ) : 0;
			
			if($action=='edit'){
				$this->easy_map_edit($value);
			}else{
				?>
				<div class="wrap">
					<h1 class="wp-heading-inline"><?php esc_attr_e( 'All Map', 'easy-map' ); ?></h1>

					<a href="<?php echo esc_url( admin_url( 'admin.php?page=easy-map-add' )); ?>" class="page-title-action"><?php esc_attr_e( 'Add New Map', 'easy-map' ); ?></a>
					
					<?php if ( isset( $_GET['map-deleted'] ) && $_GET['map-deleted'] == 'true' ) { ?>
						<div class="notice notice-success">
							<p><?php esc_attr_e( 'Map has been deleted successfully!', 'easy-map' ); ?></p>
						</div>
					<?php } ?>

					<form action="" method="post">
						<?php
						$this->admin_display->prepare_items();
						//$this->admin_display->search_box( 'search', 'search_id' );
						$this->admin_display->display();
						?>
					</form>
					<div id="easy-map-snackbar">Copied the Shortcode</div>
				</div>
				<?php
			}
		}

		
	}

	/**
     * Handle the form
     *
     * @return void
     */
    public function form_handler() {
	
        if ( ! isset( $_POST['submit_map'] ) ) {
            return;
        }

        if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['_wpnonce'] ) ), 'easy-map-add' ) ) {
            wp_die( 'Something is wrong!' );
        }

        if ( ! current_user_can( 'manage_options' ) ) {
            wp_die( 'Something is wrong!' );
            
        }

		$title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
		$lat = isset($_POST['lat']) ? sanitize_text_field($_POST['lat']) : '';
		$lon = isset($_POST['lon']) ? sanitize_textarea_field($_POST['lon']) : '';
		$zoom = isset($_POST['zoom']) ? sanitize_text_field($_POST['zoom']) : '';
		
		$popup = isset($_POST['popup']) ? wp_kses( $_POST['popup'], self::$allowed_html ) : '';

		$openPopup = isset($_POST['openPopup']) ? true : false;

		$marker = isset($_POST['marker']) ? true : false;
		$zoomControl = isset($_POST['zoomControl']) ? true : false;
		$zoomControlPosition = isset($_POST['zoomControlPosition']) ? sanitize_text_field($_POST['zoomControlPosition']) : 'topleft';

		$scrollWheelZoom = isset($_POST['scrollWheelZoom']) ? true : false;

		$fullScreen = isset($_POST['fullScreen']) ? true : false;

        if ( empty( $lat ) ) {
            $this->errors['lat'] = __('Please provide a Latitude', 'easy-map');
        }

        if ( empty( $lon ) ) {
            $this->errors['lon'] = __('Please provide a Longitude.', 'easy-map');
        }
        
        if ( empty( $zoom ) ) {
            $this->errors['zoom'] = __('Please provide a Zoom', 'easy-map');
        }

        if(empty($this->errors)){

			$this->map = [
				'title'=>$title,
				'lat' => $lat,
				'lon' => $lon,
				'zoom' => $zoom,
				'popup' => $popup,
				'openPopup' => $openPopup,
				'marker' => $marker,
				'zoomControl' => $zoomControl,
				'zoomControlPosition' => $zoomControlPosition,
				'scrollWheelZoom' => $scrollWheelZoom,
				'fullScreen' => $fullScreen,
			];
           
			$is_added = isset( $_POST['added'] ) ? sanitize_text_field(  $_POST['added']  ) : '';

			$is_edit = isset( $_POST['option_name'] ) ? true : false;

			if($is_added == 'new'){
				update_option( Easy_Map_Admin::SHORTCODE_PREPIX.time(),serialize( $this->map ), false );
				?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Map has been added successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
				
			}else if($is_edit){
				$option_name = sanitize_text_field(  $_POST['option_name']  );
				update_option( $option_name,serialize( $this->map ), false );
				?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Map has been updated successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
				echo '<script type="text/javascript">setTimeout(function(){window.location.reload(1);},1000);</script>';
			}
			else{

				$height = isset($_POST['height']) ? sanitize_text_field($_POST['height']) : 400;
				$tilelayer = isset($_POST['tilelayer']) ? sanitize_text_field($_POST['tilelayer']) : 'osm';
				$googleMapKey = isset($_POST['googleMapKey']) ? sanitize_text_field($_POST['googleMapKey']) : '';
				$bingMapKey = isset($_POST['bingMapKey']) ? sanitize_text_field($_POST['bingMapKey']) : '';

				$map_settings = [
					'tilelayer'=>$tilelayer,
					'googleMapKey' => $googleMapKey,
					'bingMapKey' => $bingMapKey,
					'height'=> $height,
				];

				$this->map = array_merge($this->map,$map_settings);
				update_option( 'easy_map_setting',serialize($this->map ), false );
				?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Map has been updated successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
				echo '<script type="text/javascript">setTimeout(function(){window.location.reload(1);},1000);</script>';
			}
        }
    }

	/**
     * Check if the form has error
     *
     * @param  string  $key
     *
     * @return boolean
     */
    public function has_error( $key ) {
        return isset( $this->errors[ $key ] ) ? true : false;
    }

    /**
     * Get the error by key
     *
     * @param  key $key
     *
     * @return string | false
     */
    public function get_error( $key ) {
        if ( isset( $this->errors[ $key ] ) ) {
            return $this->errors[ $key ];
        }

        return false;
    }

	public function easy_map_add(){
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Add Easy Map', 'easy-map' ); ?></h1>
			<?php
			echo do_shortcode("[easy-map-settings]");
					
			$easy_map_setting = $this->map_setting;

			if(!empty($_POST)){
				$this->form_handler();
			}
			?>
			
			<form action="" method="post">
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php esc_html_e( 'Map Title', 'easy-map' ); ?></label>
							</th>
							<td>
								<input type="text"  name="title" id="title" class="regular-text" value="" placeholder="Map Title">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="lat"><?php esc_html_e('Latitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error( 'lat' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['lat']); ?>" name="lat" id="lat" >
								<?php if ( $this->has_error( 'lat' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'lat' )); ?></p>
								<?php } ?>
							</td>
						</tr> 
						<tr>
							<th scope="row">
								<label for="lon"><?php esc_html_e('Longitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error( 'lon' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['lon']); ?>" name="lon" id="lon">
							    <?php if ( $this->has_error( 'lon' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'lon' )); ?></p>
								<?php } ?>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="zoom"><?php esc_html_e('Zoom', 'easy-map'); ?></label>
							</th>
							<td>
								<input  class="regular-text<?php echo esc_attr($this->has_error( 'zoom' ) ? ' easy-map-form-invalid' : '') ;?>" type="number" value="<?php echo esc_attr($easy_map_setting['zoom']); ?>" name="zoom" id="zoom">
								<?php if ( $this->has_error( 'zoom' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'zoom' )); ?></p>
								<?php } ?>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Popup', 'easy-map'); ?></label>
							</th>
							<td>
								<?php
								// Use wp_editor function to create a rich text editor
								$content = '';
								$editor_id = 'popup';
								$settings = array(
									'textarea_name' => 'popup',
									'media_buttons' => true,
									'textarea_rows' => 10,
									'teeny'         => false,
									'tinymce'       => true,
								);

								wp_editor( $content, $editor_id, $settings );
								?>
							</td>
						</tr>
						<tr> 
							<?php
							if (isset($easy_map_setting['openPopup'])) {
								$openPopup = $easy_map_setting['openPopup'];
							} else {
								$openPopup = true;
							}
							?>
							<th scope="row">
								<label for="openPopup"><?php esc_html_e('Default Open Popup', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($openPopup)
									echo esc_attr('checked'); ?> ; name="openPopup" id="openPopup">
							</td>
						</tr>
						<tr> 
							<?php
							if (isset($easy_map_setting['marker']) && $easy_map_setting['marker'] == 1) {
								$marker = true;
							} else {
								$marker = false;
							}
							?>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Default Marker', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($marker)
									echo esc_attr('checked'); ?> ; name="marker" id="marker">
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['zoomControl']) && $easy_map_setting['zoomControl'] == 1) {
								$zoom_control = true;
							} else {
								$zoom_control = false;
							}
							?>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Zoom Control', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($zoom_control)
									echo esc_attr('checked'); ?> ; name="zoomControl"
									id="zoomControl">
							</td>
						</tr>
						<tr>
							<?php
							$zoom_control_position = isset($easy_map_setting['zoomControlPosition']) ? sanitize_text_field($easy_map_setting['zoomControlPosition']) : 'topleft';
							?>
							<th scope="row">
								<label for="zoomControlPosition"><?php esc_html_e('Zoom Control Position', 'easy-map'); ?></label>
							</th>
							<td>
								<select name="zoomControlPosition" id="zoomControlPosition">
									<option <?php if ($zoom_control_position == 'topleft')
										echo esc_attr('selected'); ?> value="topleft">topleft</option>
									<option <?php if ($zoom_control_position == 'topright')
										echo esc_attr('selected'); ?> value="topright">topright</option>
									<option <?php if ($zoom_control_position == 'bottomleft')
										echo esc_attr('selected'); ?> value="bottomleft">bottomleft
									</option>
									<option <?php if ($zoom_control_position == 'bottomright')
										echo esc_attr('selected'); ?> value="bottomright">bottomright
									</option>
								</select>
						
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['scrollWheelZoom']) && $easy_map_setting['scrollWheelZoom'] == 1) {
								$scroll_wheel_zoom = true;
							} else {
								$scroll_wheel_zoom = false;
							}
							?>
							<th scope="row">
								<label for="scrollWheelZoom"><?php esc_html_e('Scroll Wheel Zoom', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($scroll_wheel_zoom)
									echo esc_attr('checked'); ?> ; name="scrollWheelZoom"
									id="scrollWheelZoom">
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['fullScreen']) && $easy_map_setting['fullScreen'] == 1) {
								$full_screen = true;
							} else {
								$full_screen = false;
							}
							?>
							<th scope="row">
								<label for="fullScreen"><?php esc_html_e('Full Screen', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($full_screen)
									echo esc_attr('checked'); ?> ; name="fullScreen" id="fullScreen">
							</td>
						</tr>

					</tbody>
				</table>
				<input type="hidden" name="added" value="new" />
				<?php wp_nonce_field( 'easy-map-add' ); ?>
				<?php submit_button( __( 'Save', 'easy-map' ), 'primary', 'submit_map' ); ?>
			</form>
		</div>
		<?php
	}

	public function easy_map_line_break() {
		return '<br>';
	}

	public	function easy_map_shortcode()
	{ ?>
		<div class="wrap">
			<h2>Shortcode Sample</h2>
			<div class="wrap">
				<div class="wrap">
					<div class="sample">
						<?php
						$samples = array(
							__("Default", 'easy-map') => array(
								'[easy-map]',
							),
							__("Lat-Lon", 'easy-map') => array(
								'[easy-map lat=37.2811806 lon=-122.0569443]',
							),
							__("Zoom", 'easy-map') => array(
								'[easy-map zoom=14 lat=37.2811806 lon=-122.0569443]',
							),
							__("Popup", 'easy-map') => array(
								'[easy-map lat=37.2811806 lon=-122.0569443 popup="Silicon Valley"]',
							),
							__("Degault Marker", 'easy-map') => array(
								'[easy-map marker=0]',
							),
							__("Zoom Control", 'easy-map') => array(
								'[easy-map zoomcontrol=0]',
							),
							__("Zoom Control Position", 'easy-map') => array(
								'[easy-map zoomcontrolposition="bottomleft"]',
							),
							__("Scroll Wheel Zoom", 'easy-map') => array(
								'[easy-map scrollwheelzoom=0]',
							),
							__("Fullscreen Control", 'easy-map') => array(
								'[easy-map fullscreen=1]',
							),
							__("Tilelayer-osm/bing/google", 'easy-map') => array(
								'[easy-map lat=37.2811806 lon=-122.0569443 tilelayer="osm"]',
							),
							__("Marker", 'easy-map') => array(
								'[easy-map lat=23.2219029 lon=90.6402413 zoom=5]',
								'[easy-map-marker lat=23.010228300829105 lon=91.38879596106436]',
								'[easy-map-marker lat=24.010228300829105 lon=92.38879596106436]'
							),
							__("Polyline", 'easy-map') => array(
								'[easy-map lat=23.2219029 lon=90.6402413 zoom=5]',
								'[easy-map-polyline latlons="23.2219029,90.6402413 - 23.010228300829105,91.38879596106436 - 24.010228300829105, 92.38879596106436 "]',
							),

							
							

						);
						foreach ($samples as $key => $value) { ?>
							<div class="list">
								<h3><?php echo esc_attr($key);  ?></h3>
								<?php
								foreach ($value as $shortcode) {
									echo do_shortcode($shortcode);
									echo esc_attr($shortcode);
									echo do_shortcode("[easy-map-br]");
								} ?>
							</div>
						<?php } ?>
					</div>
				</div>
			</div>
		</div>
	<?php }



	public	function easy_map_settings()
	{
	?>
		<div class="wrap">
			<h1><?php esc_html_e('Easy Map', 'easy-map'); ?></h1>
			<?php
			echo do_shortcode("[easy-map-settings]");
		
			$easy_map_setting = $this->map_setting;

			if(!empty($_POST)){
				$this->form_handler();
			}
			
			?>
			<h1>
				<?php esc_html_e('Short Code:', 'easy-map'); ?>
				<strong><code class="easy-map-code"> [easy-map] </code></strong>
				<h1>
					<div id="content"></div>
					<form action="" method="post">
						<table class="form-table">
							<tbody>
								<tr>
									<th scope="row">
										<label for="lat"><?php esc_html_e('Latitude', 'easy-map'); ?></label>
									</th>
									<td>
										<input class="regular-text<?php echo esc_attr($this->has_error( 'lat' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['lat']); ?>" name="lat" id="lat" >
										<?php if ( $this->has_error( 'lat' ) ) { ?>
											<p class="description error"><?php echo esc_attr( $this->get_error( 'lat' )); ?></p>
										<?php } ?>
									</td>
								</tr>
								<tr>
									<th scope="row">
										<label for="lon"><?php esc_html_e('Longitude', 'easy-map'); ?></label>
									</th>
									<td>
										<input class="regular-text<?php echo esc_attr($this->has_error( 'lon' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['lon']); ?>" name="lon" id="lon">
										<?php if ( $this->has_error( 'lat' ) ) { ?>
											<p class="description error"><?php echo esc_attr( $this->get_error( 'lat' )); ?></p>
										<?php } ?>
									</td>
								</tr>
								<tr>
									<th scope="row">
										<label for="zoom"><?php esc_html_e('Zoom', 'easy-map'); ?></label>
									</th>
									<td>
										<input class="regular-text<?php echo esc_attr($this->has_error( 'zoom' ) ? ' easy-map-form-invalid' : '') ;?>" type="number" value="<?php echo esc_attr($easy_map_setting['zoom']); ?>" name="zoom" id="zoom">
									</td>
								</tr>
								<tr>
									<?php $height = isset($easy_map_setting['height']) ? $easy_map_setting['height'] : 400; ?>
									<th scope="row">
										<label for="height"><?php esc_html_e('Height', 'easy-map'); ?></label>
									</th>
									<td>
										<input class="regular-text<?php echo esc_attr($this->has_error( 'height' ) ? ' easy-map-form-invalid' : '') ;?>" type="number" value="<?php echo esc_attr($height); ?>" name="height" id="height">
									</td>
								</tr>
								<tr>
									<th scope="row">
										<label for="popup"><?php esc_html_e('Popup', 'easy-map'); ?></label>
									</th>
									<td>
										<?php
										// Use wp_editor function to create a rich text editor
										$content = $easy_map_setting['popup'];
										$editor_id = 'popup';
										$settings = array(
											'textarea_name' => 'popup',
											'media_buttons' => true,
											'textarea_rows' => 10,
											'teeny'         => false,
											'tinymce'       => true,
										);

										wp_editor( $content, $editor_id, $settings );
										?>
									</td>
								</tr>
								<tr>
									<?php
									if(isset($easy_map_setting['openPopup'])){
										$openPopup = $easy_map_setting['openPopup'];
									}
									else{
										$openPopup = true;
									}
									?>
									<th scope="row" >
										<label for="openPopup"><?php esc_html_e('Default Open Popup', 'easy-map'); ?></label>
									</th>
									<td class="check-column" >
										<input type="checkbox" <?php if($openPopup) echo esc_attr('checked'); ?> ; name="openPopup" id="openPopup">
									</td>
								</tr>
								<tr>
									<?php
									if(isset($easy_map_setting['marker']) && $easy_map_setting['marker']==1){
										$marker = true;
									}
									else{
										$marker = false;
									}
									?>
									<th scope="row" >
										<label for="popup"><?php esc_html_e('Default Marker', 'easy-map'); ?></label>
									</th>
									<td class="check-column" >
										<input type="checkbox" <?php if($marker) echo esc_attr('checked'); ?> ; name="marker" id="marker">
									</td>
								</tr>
								<tr>
									<?php
									if(isset($easy_map_setting['zoomControl']) && $easy_map_setting['zoomControl']==1){
										$zoom_control = true;
									}
									else{
										$zoom_control = false;
									}
									?>
									<th scope="row" >
										<label for="popup"><?php esc_html_e('Zoom Control', 'easy-map'); ?></label>
									</th>
									<td class="check-column" >
										<input type="checkbox" <?php if($zoom_control) echo esc_attr('checked'); ?> ; name="zoomControl" id="zoomControl">
									</td>
								</tr>
								<tr>
									<?php
									$zoom_control_position = isset($easy_map_setting['zoomControlPosition']) ? sanitize_text_field($easy_map_setting['zoomControlPosition']) : 'topleft';
									?>
									<th scope="row">
										<label for="zoomControlPosition"><?php esc_html_e('Zoom Control Position', 'easy-map'); ?></label>
									</th>
									<td>
										<select name="zoomControlPosition" id="zoomControlPosition">
											<option <?php if ($zoom_control_position == 'topleft') echo esc_attr('selected'); ?> value="topleft">topleft</option>
											<option <?php if ($zoom_control_position == 'topright') echo esc_attr('selected'); ?> value="topright">topright</option>
											<option <?php if ($zoom_control_position == 'bottomleft') echo esc_attr('selected'); ?> value="bottomleft">bottomleft</option>
											<option <?php if ($zoom_control_position == 'bottomright') echo esc_attr('selected'); ?> value="bottomright">bottomright</option>
										</select>

									</td>
								</tr>
								<tr>
									<?php
									if(isset($easy_map_setting['scrollWheelZoom']) && $easy_map_setting['scrollWheelZoom']==1){
										$scroll_wheel_zoom = true;
									}
									else{
										$scroll_wheel_zoom = false;
									}
									?>
									<th scope="row" >
										<label for="scrollWheelZoom"><?php esc_html_e('Scroll Wheel Zoom', 'easy-map'); ?></label>
									</th>
									<td class="check-column" >
										<input type="checkbox" <?php if($scroll_wheel_zoom) echo esc_attr('checked'); ?> ; name="scrollWheelZoom" id="scrollWheelZoom">
									</td>
								</tr>
								<tr>
									<?php
									if(isset($easy_map_setting['fullScreen']) && $easy_map_setting['fullScreen']==1){
										$full_screen = true;
									}
									else{
										$full_screen = false;
									}
									?>
									<th scope="row" >
										<label for="fullScreen"><?php esc_html_e('Full Screen', 'easy-map'); ?></label>
									</th>
									<td class="check-column" >
										<input type="checkbox" <?php if($full_screen) echo esc_attr('checked'); ?> ; name="fullScreen" id="fullScreen">
									</td>
								</tr>
								<tr>
									<?php
									$tilelayer = isset($easy_map_setting['tilelayer']) ? sanitize_text_field($easy_map_setting['tilelayer']) : 'osm';

									$googleMapKey = isset($easy_map_setting['googleMapKey']) ? sanitize_text_field($easy_map_setting['googleMapKey']) : '';
									$bingMapKey = isset($easy_map_setting['bingMapKey']) ? sanitize_text_field($easy_map_setting['bingMapKey']) : '';
									?>
									<th scope="row">
										<label for="tilelayer"><?php esc_html_e('Defalut Tile Layer', 'easy-map'); ?></label>
									</th>
									<td>
										<select name="tilelayer" id="tilelayer">
											<option <?php if ($tilelayer == 'osm') echo esc_attr('selected'); ?> value="osm">Open Street Map</option>
											<option <?php if ($tilelayer == 'google') echo esc_attr('selected'); ?> value="google">Google Map</option>
											<option <?php if ($tilelayer == 'bing') echo esc_attr('selected'); ?> value="bing">Bing Map</option>
										</select>

									</td>
								</tr>
								<tr>
									<th scope="row">
										<label for="googleMapKey"><?php esc_html_e('Google Map Key', 'easy-map'); ?></label>
									</th>
									<td>
										<input type="text" value="<?php echo esc_attr($googleMapKey); ?>" name="googleMapKey" id="googleMapKey" class="regular-text" value="">
									</td>
								</tr>
								<tr>
									<th scope="row">
										<label for="bingMapKey"><?php esc_html_e('Bing Map Key', 'easy-map'); ?></label>
									</th>
									<td>
										<input type="text" value="<?php echo esc_attr($bingMapKey); ?>" name="bingMapKey" id="bingMapKey" class="regular-text" value="">
									</td>
								</tr>
								
							</tbody>
						</table>

						<?php wp_nonce_field( 'easy-map-add' ); ?>
						<?php submit_button( __( 'Update', 'easy-map' ), 'primary', 'submit_map' ); ?>
					</form>
		</div>
	<?php
	}

	
	public	function easy_map_edit_render($atts)
	{

		//$easy_map_setting = Easy_Map_Settings::getSetting();
		$easy_map_setting = $this->map_setting;

		if (!empty($atts)) {

			$lat    = isset($atts['lat']) ? sanitize_text_field($atts['lat']) : $easy_map_setting['lat'];
			$lon = isset($atts['lon']) ? sanitize_textarea_field($atts['lon']) : $easy_map_setting['lon'];
			$zoom   = isset($atts['zoom']) ? sanitize_text_field($atts['zoom']) : $easy_map_setting['zoom'];
			$popup   = isset($atts['popup']) ? sanitize_text_field($atts['popup']) : 0;

			
			if(isset($atts['marker']) && $atts['marker']){
				$marker = true;
			}
			else{
				$marker = false;
			}

			if(isset($atts['zoomcontrol']) && $atts['zoomcontrol']){
				$zoomControl = true;
			}
			else{
				$zoomControl = false;
			}

			$zoomControlPosition   = isset($atts['zoomcontrolposition']) ? sanitize_text_field($atts['zoomcontrolposition']) : $easy_map_setting['zoomControlPosition'];

			if(isset($atts['scrollwheelzoom']) && $atts['scrollwheelzoom']){
				$scrollwheelzoom = true;
			}
			else{
				$scrollwheelzoom = false;
			}

			if(isset($atts['$fullScreen']) && $atts['$fullScreen']){
				$fullScreen = true;
			}
			else{
				$fullScreen = false;
			}

			$tilelayer   = isset($atts['tilelayer']) ? sanitize_text_field($atts['tilelayer']) : $easy_map_setting['tilelayer'];

			$googleMapKey  =  isset($easy_map_setting['googleMapKey']) ? sanitize_text_field($easy_map_setting['googleMapKey']) : '';
			$bingMapKey  = isset($easy_map_setting['bingMapKey']) ? sanitize_text_field($easy_map_setting['bingMapKey']) : '';


			$setting = [
				'lat' => $lat,
				'lon' => $lon,
				'zoom' => $zoom,
				'popup' => $popup,
				'marker' => $marker,
				'zoomControl' => $zoomControl,
				'zoomControlPosition' => $zoomControlPosition,
				'scrollwheelzoom' => $scrollwheelzoom,
				'fullScreen' => $fullScreen,
				'tilelayer' => $tilelayer,
				'googleMapKey' => $googleMapKey,
				'bingMapKey' => $bingMapKey,
			];
			$easy_map_setting = wp_json_encode($setting);
		} else {
			$easy_map_setting = wp_json_encode($easy_map_setting);
		}

		$easy_map_script_params = array(
			'easy_map_setting' => $easy_map_setting
		);
		wp_localize_script('easy_map_custom_js', 'easy_map_script_params', $easy_map_script_params);
		return '<div id="easy_map" class="map map-home" style="height: 400px; margin-top: 10px; width:100%"></div>';
	}


	public	function easy_map_settings_render($atts)
	{

		//$easy_map_setting = Easy_Map_Settings::getSetting();
		$easy_map_setting = $this->map_setting;

		$easy_map_setting = wp_json_encode($easy_map_setting);
		

		$easy_map_script_params = array(
			'easy_map_setting' => $easy_map_setting
		);
		wp_localize_script('easy_map_custom_js', 'easy_map_script_params', $easy_map_script_params);
		return '<div id="easy_map" class="map map-home" style="height: 400px; margin-top: 10px; width:100%"></div>';
	}
}