<?php
/**
 * The draw-specific functionality of the plugin.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.5.0
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/draw
 */

/**
 * The draw-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/draw
 * @author     Easy Soft <nashirbabu@gmail.com>
 */

 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/easy-map-draw-display.php';

class Easy_Map_Draw extends Easy_Map_Admin
{

    /**
	 * The Display of this plugin.
	 *
	 * @since    1.4.4
	 * @access   protected
	 * @var      object    $location_display    Location Display class object.
	 */

	protected $draw_display;

    public function __construct($plugin_name, $version)
    {   
        parent::__construct($plugin_name, $version);
        $this->plugin_name = $plugin_name;
		$this->version = $version;
        
    }


    public function easy_map_draw(){
	
		if (current_user_can('manage_options')) {

			$this->draw_display = new Easy_Map_Draw_Display();

			$action = isset( $_GET['action'] ) ? $_GET['action'] : '';
			$id  = isset( $_GET['id'] ) ? intval( $_GET['id'] ) : 0;
			
			if($action=='view'){
				add_shortcode('easy-map-draw', [$this, 'easy_map_draw_render']);
				$this->easy_map_view_draw($id);
			}else{
				?>
				<div class="wrap">
					<h1 class="wp-heading-inline"><?php esc_attr_e( 'All Drawings', 'easy-map' ); ?></h1>

					<a href="<?php echo esc_url(admin_url( 'admin.php?page=easy-map-add-draw' )); ?>" class="page-title-action"><?php esc_attr_e( 'Add New Drawing', 'easy-map' ); ?></a>
					
					<?php if ( isset( $_GET['draw-deleted'] ) && $_GET['draw-deleted'] == 'true' ) { ?>
						<div class="notice notice-success">
							<p><?php esc_attr_e( 'Drawing has been deleted successfully!', 'easy-map' ); ?></p>
						</div>
					<?php } ?>

					<form action="" method="post">
						<?php
						$this->draw_display->prepare_items();
						//$this->location_display->search_box( 'search', 'search_id' );
						$this->draw_display->display();
						?>
					</form>
					<div id="easy-map-snackbar">Copied the Shortcode</div>
				</div>
				<?php
			}
		}
    }

	public function easy_map_view_draw($id){
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'View Easy Map Drawing', 'easy-map' ); ?></h1>
			<?php

			$easy_map_setting  = $this->draw_display->get_drawing($id);
			$easy_map_setting  = (array) $easy_map_setting;


			$polyline = (array) json_decode($easy_map_setting['polyline']);
			$polygon = (array) json_decode($easy_map_setting['polygon']);
			$marker = (array) json_decode($easy_map_setting['marker']);

			if(!empty($polyline)){
				$easy_map_setting['lat'] = $polyline[0][0][0];
				$easy_map_setting['lon'] = $polyline[0][0][1];
			}else if(!empty($polygon)){
				$easy_map_setting['lat'] = $polygon[0][0][0];
				$easy_map_setting['lon'] = $polygon[0][0][1];
			}else if(!empty($marker)){
				$easy_map_setting['lat'] = $marker[0][0];
				$easy_map_setting['lon'] = $marker[0][1];
			}

			$this->map_setting = $easy_map_setting;

			
		    echo do_shortcode("[easy-map-draw]");
			
			if(!empty($_POST)){
				$this->form_handler();
			}
			?>
			
			<form action="" method="post">
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php esc_html_e( 'Title', 'easy-map' ); ?></label>
							</th>
							<td>
								<input type="text"  name="title" id="title" class="regular-text<?php echo esc_attr($this->has_error( 'title' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['title']); ?>" placeholder="Title">
                                <?php if ( $this->has_error( 'title' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'title' )); ?></p>
								<?php } ?>
                            </td>
						</tr>
						
					</tbody>
				</table>
				<input type="hidden" name="id" value="<?php echo esc_attr($id); ?>" />
				<input type="hidden" name="polyline" id="polyline" value="">
				<input type="hidden" name="polygon" id="polygon" value="">
				<?php wp_nonce_field( 'easy-map-add-draw' ); ?>
				
				
			</form>
		</div>
		<?php
	}
    
    public function easy_map_add_draw(){
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Add Easy Map Drawing', 'easy-map' ); ?></h1>
			<?php
			echo do_shortcode("[easy-map-draw]");
					
            $easy_map_setting = $this->map_setting;
            
			if(!empty($_POST)){
				$this->form_handler();
			}
			?>
			<?php if ( $this->has_error( 'drawing' ) ) { ?>
				<div class="notice notice-error">
					<p><?php echo esc_attr($this->errors['drawing']); ?></p>
				</div>
			<?php } ?>
			<form action="" method="post">
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php esc_html_e( 'Title', 'easy-map' ); ?></label>
							</th>
							<td>
								<input type="text"  name="title" id="title" class="regular-text<?php echo esc_attr($this->has_error( 'title' ) ? ' easy-map-form-invalid' : '') ;?>" value="" placeholder="Title">
                                <?php if ( $this->has_error( 'title' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'title' )); ?></p>
								<?php } ?>
                            </td>
						</tr>
					</tbody>
				</table>
				<input type="hidden" name="polyline" id="polyline" value="">
				<input type="hidden" name="polygon" id="polygon" value="">
				<input type="hidden" name="marker" id="marker" value="">
				<?php wp_nonce_field( 'easy-map-add-draw' ); ?>
				<?php submit_button( __( 'Save', 'easy-map' ), 'primary', 'submit_map_draw' ); ?>
			</form>
		</div>
		<?php
	}

    /**
     * Handle the form
     *
     * @return void
     */
    public function form_handler() {

        if ( ! isset( $_POST['submit_map_draw'] ) ) {
            return;
        }

        if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['_wpnonce'] ) ), 'easy-map-add-draw' ) ) {
            wp_die( 'Something is wrong!' );
        }

        if ( ! current_user_can( 'manage_options' ) ) {
            wp_die( 'Something is wrong!' );
            
        }

		$id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : 0;
		$title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
		$polyline = isset($_POST['polyline']) ? sanitize_text_field($_POST['polyline']) : '';
		$polygon = isset($_POST['polygon']) ? sanitize_text_field($_POST['polygon']) : '';
		$marker = isset($_POST['marker']) ? sanitize_text_field($_POST['marker']) : '';


        if ( empty( $title ) ) {
            $this->errors['title'] = __('Please provide a Drawing Title', 'easy-map');
        }
		if ( empty( $polyline ) &&  empty( $polygon ) && empty( $marker )) {
            $this->errors['drawing'] = __('Please provide a Drawing ', 'easy-map');
        }


        if(empty($this->errors)){

			$args = [
				'title'=>$title,
				'polyline' =>$polyline,
				'polygon' =>$polygon,
				'marker' =>$marker,
				
			];
			
			if ( isset($id) ) {
                $args['id'] = $id;
            }
    
            $insert_id = $this->easy_map_insert_drawing( $args );
    
            if ( is_wp_error( $insert_id ) ) {
                wp_die( esc_attr($insert_id->get_error_message()) );
            }
    
            if ( $id ) {
                ?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Drawing has been updated successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
            } else {
                ?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Drawing has been added successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
            }
    
        }
	}

	/**
     * Check if the form has error
     *
     * @param  string  $key
     *
     * @return boolean
     */
    public function has_error( $key ) {
        return isset( $this->errors[ $key ] ) ? true : false;
    }

    /**
     * Get the error by key
     *
     * @param  key $key
     *
     * @return string | false
     */
    public function get_error( $key ) {
        if ( isset( $this->errors[ $key ] ) ) {
            return $this->errors[ $key ];
        }

        return false;
    }

    /**
     * Insert a new address
     *
     * @param  array  $args
     *
     * @return int|WP_Error
    */

    public function easy_map_insert_drawing( $args = [] ) {
        global $wpdb;

        if ( empty( $args['title'] ) ) {
            return new \WP_Error( 'no-title', __( 'You must provide a title.', 'easy-map' ) );
        }

        $defaults = [
            'title'       => '',
            'polyline'    => '',
            'polygon'    => '',
            'rectangle'   => '',
            'circle'  	  => '',
			'marker'	  => '',
			'circlemarker'=> '',
            'created_by'  => get_current_user_id(),
            'created_at'  => current_time( 'mysql' ),
        ];

        $data = wp_parse_args( $args, $defaults );

        if ( isset( $data['id'] ) && $data['id']!=0 ) {
           
            $id = $data['id'];
            unset( $data['id'] );

            $updated = $wpdb->update(
                $wpdb->prefix . EASY_MAP_DB_PREFIX . '_drawing',
                $data,
                [ 'id' => $id ],
                [
                    '%s',
                    '%s',
                    '%s',
                    '%s',
                    '%s',
					'%s',
					'%s'
                ],
                [ '%d' ]
            );

            return $updated;

        } else {

            $inserted = $wpdb->insert(
                $wpdb->prefix . EASY_MAP_DB_PREFIX . '_drawing',
                $data,
                [
                    '%s',
                    '%s',
                    '%s',
                    '%s',
                    '%s',
					'%s',
					'%s'
                ]
            );

            if ( ! $inserted ) {
                return new \WP_Error( 'failed-to-insert', __( 'Failed to insert data', 'easy-map' ) );
            }

            return $wpdb->insert_id;
        }
    }

	public	function easy_map_draw_render($atts)
	{

		$easy_map_setting = Easy_Map_Settings::getSetting();
		
		if (!empty($this->map_setting)) {

			$polyline   = isset($this->map_setting['polyline']) ? sanitize_text_field($this->map_setting['polyline']) : '';
			$polygon    = isset($this->map_setting['polygon']) ? sanitize_textarea_field($this->map_setting['polygon']) : '';
			$markers     = isset($this->map_setting['marker']) ? sanitize_textarea_field($this->map_setting['marker']) : '';
			
		
			$lat     = isset($this->map_setting['lat']) ? sanitize_text_field($this->map_setting['lat']) : $easy_map_setting['lat'];
			$lon     = isset($this->map_setting['lon']) ? sanitize_textarea_field($this->map_setting['lon']) : $easy_map_setting['lon'];
			
			$popup   = isset($this->map_setting['popup']) ? $this->map_setting['popup'] : 0;
			
			$open_popup   = isset($this->map_setting['open_popup']) ? sanitize_text_field($this->map_setting['open_popup']) : 0;

			$zoom   = isset($this->map_setting['zoom']) ? sanitize_text_field($this->map_setting['zoom']) : $easy_map_setting['zoom'];

			if(isset($easy_map_setting['marker']) && $easy_map_setting['marker']){
				$marker = true;
			}
			else{
				$marker = false;
			}

			if(isset($easy_map_setting['zoomControl']) && $easy_map_setting['zoomControl']){
				$zoomControl = true;
			}
			else{
				$zoomControl = false;
			}

			$zoomControlPosition   = isset($easy_map_setting['zoomControlPosition']) ? sanitize_text_field($easy_map_setting['zoomControlPosition']) : $easy_map_setting['zoomControlPosition'];

			if(isset($easy_map_setting['scrollWheelZoom']) && $easy_map_setting['scrollWheelZoom']){
				$scrollWheelZoom = true;
			}
			else{
				$scrollWheelZoom = false;
			}

			if(isset($easy_map_setting['fullScreen']) && $easy_map_setting['fullScreen']){
				$fullScreen = true;
			}
			else{
				$fullScreen = false;
			}
			
			$tilelayer   = isset($easy_map_setting['tilelayer']) ? sanitize_text_field($easy_map_setting['tilelayer']) : 'osm';

			$googleMapKey  =  isset($easy_map_setting['googleMapKey']) ? sanitize_text_field($easy_map_setting['googleMapKey']) : '';
			$bingMapKey  = isset($easy_map_setting['bingMapKey']) ? sanitize_text_field($easy_map_setting['bingMapKey']) : '';


			$setting = [
				'lat' => $lat,
				'lon' => $lon,
				'zoom' => $zoom,
				'popup' => $popup,
				'openPopup' => $open_popup,
				'marker' => $marker,
				'zoomControl' => $zoomControl,
				'zoomControlPosition' => $zoomControlPosition,
				'scrollWheelZoom' => $scrollWheelZoom,
				'fullScreen' => $fullScreen,
				'tilelayer' => $tilelayer,
				'googleMapKey' => $googleMapKey,
				'bingMapKey' => $bingMapKey,
				'polyline' => $polyline,
				'polygon' => $polygon,
				'markers' => $markers,
			];
			$easy_map_setting = wp_json_encode($setting);
		} else {
			$easy_map_setting = wp_json_encode($easy_map_setting);
		}

		$easy_map_draw_params = array(
			'easy_map_setting' => $easy_map_setting
		);
		wp_localize_script('easy_map_draw_js', 'easy_map_draw_params', $easy_map_draw_params);
		return '<div id="easy_map" class="map map-home" style="height: 400px; margin-top: 10px; width:100%"></div>';
	}
}