<?php
/**
 * The location-specific functionality of the plugin.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/location
 */

/**
 * The location-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/location
 * @author     Easy Soft <nashirbabu@gmail.com>
 */

 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/easy-map-location-display.php';

class Easy_Map_Location extends Easy_Map_Admin
{

    /**
	 * The Display of this plugin.
	 *
	 * @since    1.4.4
	 * @access   protected
	 * @var      object    $location_display    Location Display class object.
	 */

	protected $location_display;

    public function __construct($plugin_name, $version)
    {   
        parent::__construct($plugin_name, $version);
        $this->plugin_name = $plugin_name;
		$this->version = $version;
        
    }


    public function easy_map_location(){
	
		if (current_user_can('manage_options')) {

			$this->location_display = new Easy_Map_Location_Display();

			$action = isset( $_GET['action'] ) ? $_GET['action'] : '';
			$id  = isset( $_GET['id'] ) ? intval( $_GET['id'] ) : 0;
			
			if($action=='edit'){
				$this->easy_map_edit_location($id);
			}else{
				?>
				<div class="wrap">
					<h1 class="wp-heading-inline"><?php esc_attr_e( 'All Locations', 'easy-map' ); ?></h1>

					<a href="<?php echo esc_url(admin_url( 'admin.php?page=easy-map-add-location' )); ?>" class="page-title-action"><?php esc_attr_e( 'Add New Location', 'easy-map' ); ?></a>
					
					<?php if ( isset( $_GET['location-deleted'] ) && $_GET['location-deleted'] == 'true' ) { ?>
						<div class="notice notice-success">
							<p><?php esc_attr_e( 'Location has been deleted successfully!', 'easy-map' ); ?></p>
						</div>
					<?php } ?>

					<form action="" method="post">
						<?php
						$this->location_display->prepare_items();
						//$this->location_display->search_box( 'search', 'search_id' );
						$this->location_display->display();
						?>
					</form>
					<div id="easy-map-snackbar">Copied the Shortcode</div>
				</div>
				<?php
			}
		}
    }

	public function easy_map_edit_location($id){
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Edit Easy Map Location', 'easy-map' ); ?></h1>
			<?php

			$easy_map_setting  = $this->location_display->get_location($id);
			$easy_map_setting  = (array) $easy_map_setting;

			$this->map_setting = $easy_map_setting;

		    echo do_shortcode("[easy-map-edit-location]");
			
			if(!empty($_POST)){
				$this->form_handler();
			}
			?>
			
			<form action="" method="post">
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php esc_html_e('Title', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text" type="text" value="<?php echo esc_attr($easy_map_setting['title']); ?>" name="title" id="title">
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="lat"><?php esc_html_e('Latitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error('lat') ? ' easy-map-form-invalid' : ''); ?>"
									value="<?php echo esc_attr($easy_map_setting['lat']); ?>" name="lat" id="lat">
								<?php if ($this->has_error('lat')) { ?>
									<p class="description error"><?php echo esc_attr($this->get_error('lat')); ?></p>
								<?php } ?>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="lon"><?php esc_html_e('Longitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error('lon') ? ' easy-map-form-invalid' : ''); ?>"
									value="<?php echo esc_attr($easy_map_setting['lon']); ?>" name="lon" id="lon">
								<?php if ($this->has_error('lat')) { ?>
									<p class="description error"><?php echo esc_attr($this->get_error('lat')); ?></p>
								<?php } ?>
							</td>
						</tr>
						
						<tr>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Popup', 'easy-map'); ?></label>
							</th>
							<td>
								<?php
								// Use wp_editor function to create a rich text editor
								$content = $easy_map_setting['popup'];
								$editor_id = 'popup';
								$settings = array(
									'textarea_name' => 'popup',
									'media_buttons' => true,
									'textarea_rows' => 10,
									'teeny'         => false,
									'tinymce'       => true,
								);

								wp_editor( $content, $editor_id, $settings );
								?>
							</td>
						</tr>
						<tr>
							<?php
							if (isset($easy_map_setting['open_popup'])) {
								$open_popup = $easy_map_setting['open_popup'];
							} else {
								$open_popup = true;
							}
							?>
							<th scope="row">
								<label for="open_popup"><?php esc_html_e('Default Open Popup', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($open_popup)
									echo esc_attr('checked'); ?> ; name="open_popup" id="open_popup">
							</td>
						</tr>
					</tbody>
				</table>
				<input type="hidden" name="id" value="<?php echo esc_attr($id); ?>" />
				<?php wp_nonce_field( 'easy-map-add-location' ); ?>
				<?php submit_button( __( 'Update', 'easy-map' ), 'primary', 'submit_map_location' ); ?>
				
			</form>
		</div>
		<?php
	}
    
    public function easy_map_add_location(){
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Add Easy Map Location', 'easy-map' ); ?></h1>
			<?php
			echo do_shortcode("[easy-map-settings]");
					
            $easy_map_setting = $this->map_setting;
            
			if(!empty($_POST)){
				$this->form_handler();
			}
			?>
			
			<form action="" method="post">
				<table class="form-table">
					<tbody>
						<tr>
							<th scope="row">
								<label for="title"><?php esc_html_e( 'Location Title', 'easy-map' ); ?></label>
							</th>
							<td>
								<input type="text"  name="title" id="title" class="regular-text<?php echo esc_attr($this->has_error( 'title' ) ? ' easy-map-form-invalid' : '') ;?>" value="" placeholder="Location Title">
                                <?php if ( $this->has_error( 'title' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'title' )); ?></p>
								<?php } ?>
                            </td>
						</tr>
						<tr>
							<th scope="row">
								<label for="lat"><?php esc_html_e('Latitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error( 'lat' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['lat']); ?>" name="lat" id="lat" >
								<?php if ( $this->has_error( 'lat' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'lat' )); ?></p>
								<?php } ?>
							</td>
						</tr> 
						<tr>
							<th scope="row">
								<label for="lon"><?php esc_html_e('Longitude', 'easy-map'); ?></label>
							</th>
							<td>
								<input class="regular-text<?php echo esc_attr($this->has_error( 'lon' ) ? ' easy-map-form-invalid' : '') ;?>" value="<?php echo esc_attr($easy_map_setting['lon']); ?>" name="lon" id="lon">
							    <?php if ( $this->has_error( 'lon' ) ) { ?>
									<p class="description error"><?php echo esc_attr( $this->get_error( 'lon' )); ?></p>
								<?php } ?>
							</td>
						</tr>
						<tr>
							<th scope="row">
								<label for="popup"><?php esc_html_e('Popup', 'easy-map'); ?></label>
							</th>
							<td>
								<?php
								// Use wp_editor function to create a rich text editor
								$content = '';
								$editor_id = 'popup';
								$settings = array(
									'textarea_name' => 'popup',
									'media_buttons' => true,
									'textarea_rows' => 10,
									'teeny'         => false,
									'tinymce'       => true,
								);

								wp_editor( $content, $editor_id, $settings );
								?>
							</td>
						</tr>
						<tr> 
							<?php
							if (isset($easy_map_setting['open_popup'])) {
								$open_popup = $easy_map_setting['open_popup'];
							} else {
								$open_popup = true;
							}
							?>
							<th scope="row">
								<label for="open_popup"><?php esc_html_e('Default Open Popup', 'easy-map'); ?></label>
							</th>
							<td class="check-column">
								<input type="checkbox" <?php if ($open_popup)
									echo esc_attr('checked'); ?> ; name="open_popup" id="open_popup">
							</td>
						</tr>
					</tbody>
				</table>
				<input type="hidden" name="added" value="new" />
				<?php wp_nonce_field( 'easy-map-add-location' ); ?>
				<?php submit_button( __( 'Save', 'easy-map' ), 'primary', 'submit_map_location' ); ?>
			</form>
		</div>
		<?php
	}

    /**
     * Handle the form
     *
     * @return void
     */
    public function form_handler() {

        if ( ! isset( $_POST['submit_map_location'] ) ) {
            return;
        }

        if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['_wpnonce'] ) ), 'easy-map-add-location' ) ) {
            wp_die( 'Something is wrong!' );
        }

        if ( ! current_user_can( 'manage_options' ) ) {
            wp_die( 'Something is wrong!' );
            
        }

		$id = isset($_POST['id']) ? sanitize_text_field($_POST['id']) : 0;
		$title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
		$lat = isset($_POST['lat']) ? sanitize_text_field($_POST['lat']) : '';
		$lon = isset($_POST['lon']) ? sanitize_textarea_field($_POST['lon']) : '';
		
		
		$popup = isset($_POST['popup']) ? wp_kses( $_POST['popup'], Easy_Map_Admin::$allowed_html ) : '';

		$open_popup = isset($_POST['open_popup']) ? true : false;


        if ( empty( $title ) ) {
            $this->errors['title'] = __('Please provide a Location Title', 'easy-map');
        }

        if ( empty( $lat ) ) {
            $this->errors['lat'] = __('Please provide a Latitude', 'easy-map');
        }

        if ( empty( $lon ) ) {
            $this->errors['lon'] = __('Please provide a Longitude.', 'easy-map');
        }
        

        if(empty($this->errors)){

            $args = [
                'title'=>$title,
				'lat' => $lat,
				'lon' => $lon,
				'popup' => $popup,
				'open_popup' => $open_popup,
            ];
    
            if ( isset($id) ) {
                $args['id'] = $id;
            }
    
            $insert_id = $this->easy_map_insert_location( $args );
    
            if ( is_wp_error( $insert_id ) ) {
                wp_die( esc_attr($insert_id->get_error_message()) );
            }
    
            if ( $id ) {
                ?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Location has been updated successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
				echo '<script type="text/javascript">setTimeout(function(){window.location.reload(1);},1000);</script>';
            } else {
                ?>
				<div class="notice notice-success">
					<p><?php esc_attr_e( 'Location has been added successfully!', 'easy-map' ); ?></p>
				</div>
				<?php
            }
        }
    }

	/**
     * Check if the form has error
     *
     * @param  string  $key
     *
     * @return boolean
     */
    public function has_error( $key ) {
        return isset( $this->errors[ $key ] ) ? true : false;
    }

    /**
     * Get the error by key
     *
     * @param  key $key
     *
     * @return string | false
     */
    public function get_error( $key ) {
        if ( isset( $this->errors[ $key ] ) ) {
            return $this->errors[ $key ];
        }

        return false;
    }

    /**
     * Insert a new address
     *
     * @param  array  $args
     *
     * @return int|WP_Error
    */

    public function easy_map_insert_location( $args = [] ) {
        global $wpdb;

        if ( empty( $args['title'] ) ) {
            return new \WP_Error( 'no-title', __( 'You must provide a title.', 'easy-map' ) );
        }

        $defaults = [
            'title'       => '',
            'lat'         => '',
            'lon'         => '',
            'popup'       => '',
            'open_popup'  => '',
            'created_by'  => get_current_user_id(),
            'created_at'  => current_time( 'mysql' ),
        ];

        $data = wp_parse_args( $args, $defaults );

        if ( isset( $data['id'] ) && $data['id']!=0 ) {
           
            $id = $data['id'];
            unset( $data['id'] );

            $updated = $wpdb->update(
                $wpdb->prefix . EASY_MAP_DB_PREFIX . '_locations',
                $data,
                [ 'id' => $id ],
                [
                    '%s',
                    '%s',
                    '%s',
                    '%s',
                    '%d'
                ],
                [ '%d' ]
            );

            return $updated;

        } else {

            $inserted = $wpdb->insert(
                $wpdb->prefix . EASY_MAP_DB_PREFIX . '_locations',
                $data,
                [
                    '%s',
                    '%s',
                    '%s',
                    '%s',
                    '%d'
                ]
            );

            if ( ! $inserted ) {
                return new \WP_Error( 'failed-to-insert', __( 'Failed to insert data', 'easy-map' ) );
            }

            return $wpdb->insert_id;
        }
    }

	public	function easy_map_edit_location_render($atts)
	{

		$easy_map_setting = Easy_Map_Settings::getSetting();
		
		if (!empty($this->map_setting)) {

			$lat     = isset($this->map_setting['lat']) ? sanitize_text_field($this->map_setting['lat']) : $easy_map_setting['lat'];
			$lon     = isset($this->map_setting['lon']) ? sanitize_textarea_field($this->map_setting['lon']) : $easy_map_setting['lon'];
			
			$popup   = isset($this->map_setting['popup']) ? $this->map_setting['popup'] : 0;
			
			$open_popup   = isset($this->map_setting['open_popup']) ? sanitize_text_field($this->map_setting['open_popup']) : 0;

			$zoom   = isset($this->map_setting['zoom']) ? sanitize_text_field($this->map_setting['zoom']) : $easy_map_setting['zoom'];

			if(isset($easy_map_setting['marker']) && $easy_map_setting['marker']){
				$marker = true;
			}
			else{
				$marker = false;
			}

			if(isset($easy_map_setting['zoomControl']) && $easy_map_setting['zoomControl']){
				$zoomControl = true;
			}
			else{
				$zoomControl = false;
			}

			$zoomControlPosition   = isset($easy_map_setting['zoomControlPosition']) ? sanitize_text_field($easy_map_setting['zoomControlPosition']) : $easy_map_setting['zoomControlPosition'];

			if(isset($easy_map_setting['scrollWheelZoom']) && $easy_map_setting['scrollWheelZoom']){
				$scrollWheelZoom = true;
			}
			else{
				$scrollWheelZoom = false;
			}

			if(isset($easy_map_setting['fullScreen']) && $easy_map_setting['fullScreen']){
				$fullScreen = true;
			}
			else{
				$fullScreen = false;
			}
			
			$tilelayer   = isset($easy_map_setting['tilelayer']) ? sanitize_text_field($easy_map_setting['tilelayer']) : 'osm';

			$googleMapKey  =  isset($easy_map_setting['googleMapKey']) ? sanitize_text_field($easy_map_setting['googleMapKey']) : '';
			$bingMapKey  = isset($easy_map_setting['bingMapKey']) ? sanitize_text_field($easy_map_setting['bingMapKey']) : '';


			$setting = [
				'lat' => $lat,
				'lon' => $lon,
				'zoom' => $zoom,
				'popup' => $popup,
				'openPopup' => $open_popup,
				'marker' => $marker,
				'zoomControl' => $zoomControl,
				'zoomControlPosition' => $zoomControlPosition,
				'scrollWheelZoom' => $scrollWheelZoom,
				'fullScreen' => $fullScreen,
				'tilelayer' => $tilelayer,
				'googleMapKey' => $googleMapKey,
				'bingMapKey' => $bingMapKey,
			];
			$easy_map_setting = wp_json_encode($setting);
		} else {
			$easy_map_setting = wp_json_encode($easy_map_setting);
		}

		$easy_map_script_params = array(
			'easy_map_setting' => $easy_map_setting
		);
		wp_localize_script('easy_map_custom_js', 'easy_map_script_params', $easy_map_script_params);
		return '<div id="easy_map" class="map map-home" style="height: 400px; margin-top: 10px; width:100%"></div>';
	}
}