<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.2.6
 * @package    Easy_Map
 * @subpackage Easy_Map/includes
 * @author     Easy Soft <nashirbabu@gmail.com>
 */
class Easy_Map_Settings {

	static public function setSetting(){
		
		$setting=[
			'lat'=>'37.2811806',
			'lon'=>'-122.0569443',
			'zoom'=>'13',
			'popup'=>'Silicon Valley',
			'openPopup' => true,
			'marker' => true,
			'zoomControl' => true,
			'zoomControlPosition' => 'topleft',
			'scrollWheelZoom' => true,
			'fullScreen' => false,
			'tilelayer'=>'osm',
			'googleMapKey'=>'',
			'bingMapKey'=>'',
			'height'=>'400',
		];
		update_option( 'easy_map_setting',serialize( $setting ), false );

	}

	static public function getSetting(){
		$easy_map_setting=unserialize(get_option('easy_map_setting'));

		return $easy_map_setting;
	}

	/**
     * Add time and version on DB
    */
    public static function add_version() {
       
		update_option( 'easy_map_version', EASY_MAP_VERSION );
    }

	/**
     * Create necessary database tables
     *
     * @return void
     */
    public static function create_tables() {
        global $wpdb;

        $charset_collate = $wpdb->get_charset_collate();
		$db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;

        $schema = "CREATE TABLE IF NOT EXISTS `{$db_prefix}_locations` (
          `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
          `title` varchar(255) NOT NULL DEFAULT '',
		  `lat` varchar(100) NOT NULL DEFAULT '',
		  `lon` varchar(100) NOT NULL DEFAULT '',
          `popup` text DEFAULT NULL,
          `open_popup` tinyint NOT NULL,
          `created_by` bigint(20) unsigned NOT NULL,
          `created_at` datetime NOT NULL,
          PRIMARY KEY (`id`)
        ) $charset_collate";

        if ( ! function_exists( 'dbDelta' ) ) {
            require_once ABSPATH . 'wp-admin/includes/upgrade.php';
        }

        dbDelta( $schema );

		$schema_draw = "CREATE TABLE IF NOT EXISTS `{$db_prefix}_drawing` (
			`id` int(11) unsigned NOT NULL AUTO_INCREMENT,
			`title` varchar(255) NOT NULL DEFAULT '',
			`polyline` text DEFAULT NULL,
			`polygon` text DEFAULT NULL,
			`rectangle` text DEFAULT NULL,
			`circle` text DEFAULT NULL,
			`marker` text DEFAULT NULL,
			`circlemarker` text DEFAULT NULL,
			`created_by` bigint(20) unsigned NOT NULL,
			`created_at` datetime NOT NULL,
			PRIMARY KEY (`id`)
		  ) $charset_collate";
  
		  dbDelta( $schema_draw );
    }


}