<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/admin/partials
 */

 if ( ! class_exists( 'WP_List_Table' ) ) {
    require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class Easy_Map_Admin_Display extends \WP_List_Table {

    function __construct() {
        parent::__construct( [
            'singular' => 'contact',
            'plural'   => 'contacts',
            'ajax'     => false
        ] );
        
    }

    /**
     * Message to show if no designation found
     *
     * @return void
     */
    function no_items() {
        esc_html_e( 'No item found.', 'easy-map' );
    }

    /**
     * Get the column names
     *
     * @return array
     */
    public function get_columns() {
        return [
            'cb'             => '<input type="checkbox" />',
            'shortcode'      => __( 'Shortcode', 'easy-map' ),
            'title'          => __( 'Title', 'easy-map' ),
            'lat'           => __( ' Latitude', 'easy-map' ),
            'lon'          => __( ' Longitude', 'easy-map' ),
            'zoom'         => __( ' Zoom', 'easy-map' ),
           
          
        ];
    }

    /**
     * Get sortable columns
     *
     * @return array
     */
    function get_sortable_columns() {
        $sortable_columns = [
            'shortcode'       => [ 'option_id', true ],
        ];

        return $sortable_columns;
    }

    /**
     * Set the bulk actions
     *
     * @return array
     */
    function get_bulk_actions() {
        $actions = array(
            'delete'  => __( 'Delete Permanently', 'easy-map' ),
        );

        return $actions;
    }

    /**
     * 
     */

     public function process_bulk_action() {
        
        // security check!
        if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {

            $nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_SPECIAL_CHARS  );
            $action = 'bulk-' . $this->_args['plural'];

            if ( ! wp_verify_nonce( $nonce, $action ) )
                wp_die( 'Nope! Security check failed!' );

        }

        $action = $this->current_action(); 

        switch ( $action ) {

            case 'delete':
                if(isset($_POST['option_id'])){
                    global $wpdb;
                    foreach($_POST['option_id'] as $option_id){
                        $deleted = $wpdb->delete(
                            $wpdb->options,
                            array('option_id' => $option_id),
                            array('%d')
                        );
                    }
                    if ($deleted) {
                        ?>
                        <div class="notice notice-success">
                            <p><?php esc_attr_e( 'Map has been deleted successfully!', 'easy-map' ); ?></p>
                        </div>
                        <?php
                    }
                  
                }
                break;

            default:
                // do nothing or something else
                return;
                break;
        }

        return;
    }

    /**
     * Default column values
     *
     * @param  object $item
     * @param  string $column_name
     *
     * @return string
     */
    protected function column_default( $item, $column_name ) {
        return isset( $item->$column_name ) ? $item->$column_name : '';
    }

    /**
     * Render the "name" column
     *
     * @param  object $item
     *
     * @return string
     */

    protected function handle_row_actions( $item, $column_name, $primary ) {

        $value=0;
        $values=explode('_id_',$item->option_name);
        if(is_array($values) && isset($values[1])){
            $value=$values[1];
        }
        if( $column_name === $primary){
            $actions = [];

            $actions['copy']   = sprintf( '<a href="%s" onclick="easy_map_copy('.$item->option_id.')" title="%s">%s</a>', '#', '' , __( 'Copy', 'easy-map' ), __( 'Copy', 'easy-map' ) );
            $actions['edit']   = sprintf( '<a href="%s" title="%s">%s</a>', admin_url( 'admin.php?page=easy-map&action=edit&value=' . $value ), $value, __( 'Edit', 'easy-map' ), __( 'Edit', 'easy-map' ) );
            $actions['delete'] = sprintf( '<a href="%s" class="submitdelete" onclick="return confirm(\'Are you sure?\');" title="%s">%s</a>', wp_nonce_url( admin_url( 'admin-post.php?action=easy-map-delete&value=' . $value ), 'easy-map-delete' ), $value, __( 'Delete', 'easy-map' ), __( 'Delete', 'easy-map' ) );
        

            return sprintf(
                '<a href="%1$s"><strong>%2$s</strong></a> %3$s', admin_url( 'admin.php?page=easy-map&action=view&id' . $item->option_id ),'', $this->row_actions( $actions )
            );
        }
    }

    /**
     * Render the "cb" column
     *
     * @param  object $item
     *
     * @return string
     */
    protected function column_cb( $item ) {
        return sprintf(
            '<input type="checkbox" name="option_id[]" value="%d" />', $item->option_id
        );
    }

    /**
     * Prepare the address items
     *
     * @return void
     */
    public function prepare_items() {
        $column   = $this->get_columns();
        $hidden   = [];
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = [ $column, $hidden, $sortable ];

        $this->process_bulk_action();

        $per_page     = 10;
        $current_page = $this->get_pagenum();
        $offset       = ( $current_page - 1 ) * $per_page;

        $args = [
            'number' => $per_page,
            'offset' => $offset,
        ];

        if ( isset( $_REQUEST['orderby'] ) && isset( $_REQUEST['order'] ) ) {
            $args['orderby'] = $_REQUEST['orderby'];
            $args['order']   = $_REQUEST['order'] ;
        }

        $this->items = $this->easy_map_get_shortcode( $args );
  
        foreach($this->items as $key=>$value){
            $map = unserialize(get_option($this->items[$key]->option_name));
            $this->items[$key]->title=isset($map['title']) ? $map['title']: '';
            $this->items[$key]->lat=$map['lat'];
            $this->items[$key]->lon=$map['lon'];
            $this->items[$key]->zoom=$map['zoom'];
            $this->items[$key]->shortcode='[easy-map ID="'.$this->items[$key]->option_id.'"]';
        }
        

        $this->set_pagination_args( [
            'total_items' => $this->easy_map_shourtcode_count(),
            'per_page'    => $per_page
        ] );
    }
    private function easy_map_get_shortcode( $args = [] ) {
        global $wpdb;
    
        $defaults = [
            'number'  => 20,
            'offset'  => 0,
            'orderby' => 'option_id',
            'order'   => 'ASC'
        ];
    
        $args = wp_parse_args( $args, $defaults );


        $items = $wpdb->get_results( $wpdb->prepare(
            "SELECT * FROM {$wpdb->prefix}options 
            WHERE option_name LIKE %s 
            ORDER BY {$args['orderby']} {$args['order']} 
            LIMIT %d, %d",
            '%' . $wpdb->esc_like(Easy_Map_Admin::SHORTCODE_PREPIX) . '%', // Escaped and wildcard search term
            $args['offset'], $args['number']  // Limit
        ));

        //$items = $wpdb->get_results( $sql );
    
        return $items;
    }
    
    /**
     * Get the count of total address
     *
     * @return int
     */
    private function easy_map_shourtcode_count() {
        global $wpdb;
    
        return (int) $wpdb->get_var( $wpdb->prepare( 
            "SELECT count(option_id) FROM {$wpdb->prefix}options  
            WHERE option_name LIKE %s",
            '%' . $wpdb->esc_like(Easy_Map_Admin::SHORTCODE_PREPIX) . '%'
        ));
    }

    

}
