<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/location/partials
 */

 if ( ! class_exists( 'WP_List_Table' ) ) {
    require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class Easy_Map_Location_Display extends \WP_List_Table {

    function __construct() {
        parent::__construct( [
            'singular' => 'contact',
            'plural'   => 'contacts',
            'ajax'     => false
        ] );
        
    }

    /**
     * Message to show if no designation found
     *
     * @return void
     */
    function no_items() {
        esc_html_e( 'No item found.', 'easy-map' );
    }

    /**
     * Get the column names
     *
     * @return array
     */
    public function get_columns() {
        return [
            'cb'             => '<input type="checkbox" />',
            'shortcode'      => __( 'Shortcode', 'easy-map' ),
            'title'          => __( 'Title', 'easy-map' ),
            'lat'            => __( ' Latitude', 'easy-map' ),
            'lon'            => __( ' Longitude', 'easy-map' ),
            'popup'          => __( ' Popup', 'easy-map' ),
            'created_at'     => __( ' Date', 'easy-map' ),
           
          
        ];
    }

    /**
     * Get sortable columns
     *
     * @return array
     */
    function get_sortable_columns() {
        $sortable_columns = [
            'title'       => [ 'title', true ],
            'created_at' => [ 'created_at', true ],
        ];

        return $sortable_columns;
    }

    /**
     * Set the bulk actions
     *
     * @return array
     */
    function get_bulk_actions() {
        $actions = array(
            'delete'  => __( 'Delete Permanently', 'easy-map' ),
        );

        return $actions;
    }

    /**
     * 
     */

     public function process_bulk_action() {
      
        // security check!
        if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {

            $nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_SPECIAL_CHARS );
            $action = 'bulk-' . $this->_args['plural'];

            if ( ! wp_verify_nonce( $nonce, $action ) )
                wp_die( 'Nope! Security check failed!' );

        }

        $action = $this->current_action(); 

        switch ( $action ) {

            case 'delete':
                if(isset($_POST['id'])){ 
                    global $wpdb;
                    foreach($_POST['id'] as $id){
                        $deleted = self::delete_location($id);
                    }
                    if ($deleted) {
                        ?>
                        <div class="notice notice-success">
                            <p><?php esc_attr_e( 'Map has been deleted successfully!', 'easy-map' ); ?></p>
                        </div>
                        <?php
                    }
                  
                }
                break;

            default:
                // do nothing or something else
                return;
                break;
        }

        return;
    }

    /**
     * Default column values
     *
     * @param  object $item
     * @param  string $column_name
     *
     * @return string
     */
    protected function column_default( $item, $column_name ) {

        switch ( $column_name ) {

            case 'created_at':
                return wp_date( get_option( 'date_format' ), strtotime( $item->created_at ) );

            default:
                return isset( $item->$column_name ) ? $item->$column_name : '';
        }
    }

    /**
     * Render the "name" column
     *
     * @param  object $item
     *
     * @return string
     */

    protected function handle_row_actions( $item, $column_name, $primary ) {

        if( $column_name === $primary){
            $actions = [];
       
            $actions['copy']   = sprintf( '<a href="%s" onclick="easy_map_location_copy('.$item->id.')" title="%s">%s</a>', '#', '' , __( 'Copy', 'easy-map' ), __( 'Copy', 'easy-map' ) );
            $actions['edit']   = sprintf( '<a href="%s" title="%s">%s</a>', admin_url( 'admin.php?page=easy-map-location&action=edit&id=' . $item->id  ), $item->id , __( 'Edit', 'easy-map' ), __( 'Edit', 'easy-map' ) );
            $actions['delete'] = sprintf( '<a href="%s" class="submitdelete" onclick="return confirm(\'Are you sure?\');" title="%s">%s</a>', wp_nonce_url( admin_url( 'admin-post.php?action=easy-map-location-delete&id=' . $item->id  ), 'easy-map-location-delete' ), $item->id , __( 'Delete', 'easy-map' ), __( 'Delete', 'easy-map' ) );
            
            return sprintf(
                '<a href="%1$s"><strong>%2$s</strong></a> %3$s', admin_url( 'admin.php?page=easy-map-location&action=view&id' . $item->id ),'', $this->row_actions( $actions )
            );
        }
       
        
    }
    

    /**
     * Render the "cb" column
     *
     * @param  object $item
     *
     * @return string
     */
    protected function column_cb( $item ) {
        return sprintf(
            '<input type="checkbox" name="id[]" value="%d" />', $item->id
        );
    }

    /**
     * Prepare the address items
     *
     * @return void
     */
    public function prepare_items() {

        $column   = $this->get_columns();
        $hidden   = [];
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = [ $column, $hidden, $sortable ];

        $this->process_bulk_action();

        $per_page     = 20;
        $current_page = $this->get_pagenum();
        $offset       = ( $current_page - 1 ) * $per_page;

        $args = [
            'number' => $per_page,
            'offset' => $offset,
        ];

        if ( isset( $_REQUEST['orderby'] ) && isset( $_REQUEST['order'] ) ) {
            $args['orderby'] = $_REQUEST['orderby'];
            $args['order']   = $_REQUEST['order'] ;
        }

        $this->items = $this->get_locations( $args );

        $this->set_pagination_args( [
            'total_items' => $this->locations_count(),
            'per_page'    => $per_page
        ] );
    }

    /**
     * Fetch Addresses
     *
     * @param  array  $args
     *
     * @return array
     */
    public function get_locations( $args = [] ) {
        global $wpdb;

        $defaults = [
            'number'  => 10,
            'offset'  => 0,
            'orderby' => 'id',
            'order'   => 'DESC'
        ];

        $db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;

        $args = wp_parse_args( $args, $defaults );

        $items = $wpdb->get_results( $wpdb->prepare(
                "SELECT * FROM {$db_prefix}_locations
                ORDER BY {$args['orderby']} {$args['order']}
                LIMIT %d, %d",
                $args['offset'], $args['number']
        ));
        
        foreach($items as $key=>$value){
           $items[$key]->shortcode='[easy-map-marker ID="'.$items[$key]->id.'"]';
        }

        return $items;
    }

    /**
     * Get the count of total address
     *
     * @return int
     */
    public function locations_count() {
        global $wpdb;

        $db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;

        return (int) $wpdb->get_var( "SELECT count(id) FROM {$db_prefix}_locations" );
    }

    /**
     * Fetch a single contact from the DB
     *
     * @param  int $id
     *
     * @return object
     */
    public function get_location( $id ) {
        global $wpdb;
        $db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;
        return $wpdb->get_row(
            $wpdb->prepare( "SELECT * FROM {$db_prefix}_locations WHERE id = %d", $id )
        );
    }

    
	 /**
     * Delete an location
     *
     * @param  int $id
     *
     * @return int|boolean
     */
    public static function delete_location( $id ) {
        global $wpdb;
        $db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;
        return $wpdb->delete(
            $db_prefix . '_locations',
            [ 'id' => $id ],
            [ '%d' ]
        );
    }
   
    

}
