
if (typeof easy_map_draw_params !== 'undefined'){

  var easy_map_draw_obj = JSON.parse(easy_map_draw_params.easy_map_setting);

  var mapopts = {
    zoomControl: easy_map_draw_obj.zoomControl,
    scrollWheelZoom: easy_map_draw_obj.scrollWheelZoom,
  };

  var easy_map_draw = L.map('easy_map', mapopts ).setView([easy_map_draw_obj.lat, easy_map_draw_obj.lon], easy_map_draw_obj.zoom);

  if(easy_map_draw_obj.zoomControl && !easy_map_draw_obj.fullScreen){
    L.control.zoom({
      position: easy_map_draw_obj.zoomControlPosition
    }).addTo(easy_map_draw);

    easy_map_draw.zoomControl.remove();
  }

  if(easy_map_draw_obj.fullScreen){
    easy_map_draw.addControl(L.control.fullscreen());
  }

  if(easy_map_draw_obj.tilelayer=='bing'){
    L.tileLayer.bing({
      bingMapsKey: easy_map_draw_obj.bingMapKey ,
      imagerySet: 'Road', // For road maps
    }).addTo(easy_map_draw);
  }else if(easy_map_draw_obj.tilelayer=='google'){
    L.gridLayer.googleMutant({
      id: 'roads',
      type: 'roadmap'
    }).addTo(easy_map_draw);
  }else{
    L.tileLayer('https://tile.openstreetmap.org/{z}/{x}/{y}.png', {
      attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
    }).addTo(easy_map_draw);
  }

  // leaflet draw 
  var drawnFeatures = new L.FeatureGroup();
  easy_map_draw.addLayer(drawnFeatures);

  var drawControl = new L.Control.Draw({
    position: "topright",
    edit: {
      featureGroup: drawnFeatures,
      remove: true,
      edit: false
    },
    draw: {
      polygon: {
        shapeOptions: {
          color: 'purple'
        },
      },
      polyline: {
        shapeOptions: {
          color: 'red'
        },
      },
      rect: {
        shapeOptions: {
          color: 'green'
        },
      },
      circle: {
        shapeOptions: {
          color: 'steelblue'
        },
      },
      circle: false, // Turns off this drawing tool
      rectangle: false,
      marker: true,
      circlemarker: false,
    },

  });
  easy_map_draw.addControl(drawControl);

  easy_map_draw.eachLayer(function(layer) {
    if (layer.editing && layer.editing.enabled()) {
      layer.editing.disable();
    }
  });

  if(easy_map_draw_obj.polyline){
    var polylines = JSON.parse(easy_map_draw_obj.polyline);
    L.polyline(polylines, {color: 'red'}).addTo(easy_map_draw);
  }

  if(easy_map_draw_obj.polygon){
    var polygons = JSON.parse(easy_map_draw_obj.polygon);
    L.polygon(polygons, {color: 'purple'}).addTo(easy_map_draw);
  }

  if(easy_map_draw_obj.markers){

    var fixedJson = easy_map_draw_obj.markers.replace(/\\/g, ""); // Remove backslashes
    var markers = JSON.parse(fixedJson);

    for (let i in markers) {
      if(markers[i][2])
        L.marker([markers[i][0], markers[i][1]]).addTo(easy_map_draw).bindPopup(markers[i][2]);
      else
        L.marker([markers[i][0], markers[i][1]]).addTo(easy_map_draw);
    }
    
  }

  var polylineData = [];
  var polygonData = [];
  var markerData = [];

  easy_map_draw.on("draw:created", function(e){

      var type = e.layerType;
      var layer = e.layer;

      //layer.bindPopup(`<p>${JSON.stringify(layer.toGeoJSON())}</p>`)
      drawnFeatures.addLayer(layer);


      if (type === 'polyline') {
        var coords = layer._latlngs;
        var polyline =[];
        for (let i in coords) {
          polyline[i] = [];
          polyline[i][0] = coords[i]['lat'];
          polyline[i][1] = coords[i]['lng'];
        }
        polylineData.push(polyline);
      }


      if (type === 'polygon') {
        var polygon =[];
        var coords = layer._latlngs[0];
        for (let i in coords) {
          polygon[i] = [];
          polygon[i][0] = coords[i]['lat'];
          polygon[i][1] = coords[i]['lng'];
        }
        polygonData.push(polygon);
      }

    
      if (type === 'marker') {
       
        var markerPopup = '';
        var popupContent = prompt("Enter popup message for the marker:", "Default Popup Text"); // Prompt for popup content
        if (popupContent !== null && popupContent.trim() !== "") { // Check if user entered anything
          layer.bindPopup(popupContent).openPopup();  // Bind the popup and immediately open it
          markerPopup = layer._popup._content;
        }

        var coords = layer._latlng;

        var marker =[];
        marker[0] = coords['lat'];
        marker[1] = coords['lng'];
        marker[2] = markerPopup; 

        markerData.push(marker);

      }

      document.getElementById('polyline').value = JSON.stringify(polylineData);
      document.getElementById('polygon').value = JSON.stringify(polygonData);
      document.getElementById('marker').value = JSON.stringify(markerData);
  });

}
