<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://eeasy-soft.com/
 * @since             1.2.6
 * @package           Easy_Map
 *
 * @wordpress-plugin
 * Plugin Name:       Easy Map
 * Plugin URI:        https://wordpress.org/plugins/easy-map
 * Description:       Interactive maps, markers, polylines and polygons on your posts and pages with simple auto generated shortcodes.
 * Version:           1.6.6
 * Author:            Easy Soft
 * Author URI:        https://profiles.wordpress.org/nashirbabu/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-map
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit; 
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'EASY_MAP_VERSION', '1.6.6' );
define( 'EASY_MAP_DB_PREFIX', 'easy_map' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-easy-map-activator.php
 */
function activate_easy_map() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-easy-map-activator.php';
	Easy_Map_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-easy-map-deactivator.php
 */
function deactivate_easy_map() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-easy-map-deactivator.php';
	Easy_Map_Deactivator::deactivate();
}

/**
 * The code that runs during plugin uninstall.
 * This action is documented in uninstall.php
 */
function uninstall_easy_map() {
	require_once plugin_dir_path( __FILE__ ) . 'uninstall.php';
	easy_map_uninstall();
}

register_activation_hook( __FILE__, 'activate_easy_map' );
register_deactivation_hook( __FILE__, 'deactivate_easy_map' );
register_uninstall_hook( __FILE__, 'uninstall_easy_map' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-easy-map.php';

require_once plugin_dir_path( __FILE__ ) . 'includes/helper.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.2.6
 */
function run_easy_map() {

	$plugin = new Easy_Map();
	$plugin->run();

}
run_easy_map();

function easy_map_block_init() {
	register_block_type(
		__DIR__ . '/build'
	);
}
add_action('init', 'easy_map_block_init');
