<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://eeasy-soft.com/
 * @since      1.2.6
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Easy_Map
 * @subpackage Easy_Map/public
 * @author     Easy Soft <nashirbabu@gmail.com>
 */
class Easy_Map_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.2.6
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.2.6
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.3.0
	 * @access   private
	 * @var      string    $map    The current leaflet unique map id.
	 */
    private $map;

    /**
	 * The version of this plugin.
	 *
	 * @since    1.3.0
	 * @access   private
	 * @var      string    $easy_map    The current leaflet map obejct.
	 */
    private $easy_map;

	private $easy_map_marker;

	private $easy_map_polyline;

	private $easy_map_val;

	private $map_height;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.3.4
	 * @access   private
	 * @var      string    $map_setting    The current version of this plugin.
	 */
	private $map_setting;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since      1.2.6
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->map_setting = Easy_Map_Settings::getSetting();
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.2.6
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Map_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Map_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/easy-map-public.css', array(), $this->version, 'all');

		wp_register_style('easy_map_css', plugins_url('../assets/leaflet/leaflet.css', __FILE__));
		wp_enqueue_style('easy_map_css');


		wp_register_style('easy_map_custom_css', plugins_url('../assets/css/easy_map.css', __FILE__), null, null, false);
		wp_enqueue_style('easy_map_custom_css');

		
		wp_register_style('easy_map_fullscreen', plugins_url('../assets/leaflet/FullScreen.css', __FILE__),null, null, false);
		wp_enqueue_style('easy_map_fullscreen');
		

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.2.6
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Map_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Map_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . '../assets/js/easy_map_public.js', array('jquery'), $this->version, false);

		wp_register_script('easy_map_js', plugins_url('../assets/leaflet/leaflet.js', __FILE__), null, null, false);
		wp_enqueue_script('easy_map_js');

		wp_register_script('easy_map_bing', plugins_url('../assets/leaflet/leaflet-bing-layer.js', __FILE__), null, null, false);
		wp_enqueue_script('easy_map_bing');

		if (isset($this->map_setting['googleMapKey']) && $this->map_setting['googleMapKey'] != '') {
			wp_register_script('easy_map_key', 'https://maps.googleapis.com/maps/api/js?key=' . $this->map_setting['googleMapKey'], null, null, false);
			wp_enqueue_script('easy_map_key');

			wp_register_script('easy_map_google', plugins_url('../assets/leaflet/GoogleMutant.js', __FILE__), null, null, false);
			wp_enqueue_script('easy_map_google');
		}

		
		wp_register_script('easy_map_fullscreen', plugins_url('../assets/leaflet/FullScreen.js', __FILE__), null, null, false);
		wp_enqueue_script('easy_map_fullscreen');

		wp_register_script('easy_map_frontend_js', plugins_url('js/easy_map_frontend.js', __FILE__),  array('jquery'), $this->version, false);
		wp_enqueue_script('easy_map_frontend_js');

	}

	private function get_option_by_id($option_id) {
		global $wpdb;
	
		// Get the option name associated with the option ID
		$option_name = $wpdb->get_var(
			$wpdb->prepare("SELECT option_name FROM {$wpdb->options} WHERE option_id = %d", $option_id)
		);
	
		// Retrieve the option value using the option name
		if ($option_name) {
			return unserialize(get_option($option_name));
		} else {
			return false; // Option not found
		}
	}

	public	function easy_map_render($atts,$content,$tag)
	{
		
		$easy_map_setting = $this->map_setting;
		$this->map = uniqid();

		$this->map_height= isset($easy_map_setting['height']) ? sanitize_text_field($easy_map_setting['height']) : 400;


		if (!empty($atts)) {


			if (isset($atts['id']) && $atts['id'] != "" && is_numeric($atts['id'])) {
				
				$easy_map_setting= $this->get_option_by_id($atts['id']);

				$default_tilelayer = isset($easy_map_setting['tilelayer']) ? $easy_map_setting['tilelayer'] : 'osm';

				$tilelayer = isset($atts['tilelayer']) ? sanitize_text_field($atts['tilelayer']) : $default_tilelayer;

				$googleMapKey = isset($easy_map_setting['googleMapKey']) ? sanitize_text_field($easy_map_setting['googleMapKey']) : '';
				$bingMapKey = isset($easy_map_setting['bingMapKey']) ? sanitize_text_field($easy_map_setting['bingMapKey']) : '';

				
				$map_settings = [
					'tilelayer'=>$tilelayer,
					'googleMapKey' => $googleMapKey,
					'bingMapKey' => $bingMapKey,
				];

				if(is_array($easy_map_setting))
					$easy_map_setting = array_merge($easy_map_setting,$map_settings);
			} else {

				$lat = isset($atts['lat']) ? sanitize_text_field($atts['lat']) : $easy_map_setting['lat'];
				$lon = isset($atts['lon']) ? sanitize_textarea_field($atts['lon']) : $easy_map_setting['lon'];
				$zoom = isset($atts['zoom']) ? sanitize_text_field($atts['zoom']) : $easy_map_setting['zoom'];
				$popup = isset($atts['popup']) ? sanitize_text_field($atts['popup']) : 0;

				if (isset($atts['openPopup'])) {
					$openPopup = ($atts['openPopup']) ? 1 : 0;
				} else {

					$openPopup = (isset($easy_map_setting['openPopup'])) ? sanitize_text_field($easy_map_setting['openPopup']) : 1;
				}

				if (isset($atts['marker'])) {
					$marker = ($atts['marker']) ? 1 : 0;
				} else {

					$marker = (isset($easy_map_setting['marker'])) ? sanitize_text_field($easy_map_setting['marker']) : 1;
				}

				if (isset($atts['zoomcontrol'])) {
					$zoomControl = ($atts['zoomcontrol']) ? 1 : 0;
				} else {
					$zoomControl = sanitize_text_field($easy_map_setting['zoomControl']);
				}

				$zoomControlPosition = isset($atts['zoomcontrolposition']) ? sanitize_text_field($atts['zoomcontrolposition']) : $easy_map_setting['zoomControlPosition'];

				if (isset($atts['scrollwheelzoom'])) {
					$scrollWheelZoom = ($atts['scrollwheelzoom']) ? 1 : 0;
				} else {
					$scrollWheelZoom = sanitize_text_field($easy_map_setting['scrollWheelZoom']);
				}

				if (isset($atts['fullscreen'])) {
					$fullScreen = ($atts['fullscreen']) ? 1 : 0;
				} else {
					$fullScreen = 0;
				}

				$default_tilelayer = isset($easy_map_setting['tilelayer']) ? $easy_map_setting['tilelayer'] : 'osm';

				$tilelayer = isset($atts['tilelayer']) ? sanitize_text_field($atts['tilelayer']) : $default_tilelayer;

				$googleMapKey = isset($easy_map_setting['googleMapKey']) ? sanitize_text_field($easy_map_setting['googleMapKey']) : '';
				$bingMapKey = isset($easy_map_setting['bingMapKey']) ? sanitize_text_field($easy_map_setting['bingMapKey']) : '';

				$setting = [
					'lat' => $lat,
					'lon' => $lon,
					'zoom' => $zoom,
					'popup' => $popup,
					'openPopup' => $openPopup,
					'marker' => $marker,
					'zoomControl' => $zoomControl,
					'zoomControlPosition' => $zoomControlPosition,
					'scrollWheelZoom' => $scrollWheelZoom,
					'fullScreen' => $fullScreen,
					'tilelayer' => $tilelayer,
					'googleMapKey' => $googleMapKey,
					'bingMapKey' => $bingMapKey
				];

				$easy_map_setting = $setting;
			}

			
		}
		
		if(!empty($easy_map_setting)){

			ob_start();

			?>
			<div id="<?php echo esc_attr($this->map); ?>" class="easy-map" style="height: <?php echo esc_attr($this->map_height); ?>px; margin-top: 10px; width:100%"></div>
			<?php

			$this->easy_map = $easy_map_setting;
			$this->easy_map_dom_render(  );
		
			return ob_get_clean();

		}else{
			$this->easy_map = [];
		}
	}

	private function easy_map_dom_render( ){  
		$openPopup = 1;
		if(isset($this->easy_map['openPopup']) && $this->easy_map['openPopup']==1){
			$openPopup = 1;
		}
		if(isset($this->easy_map['openPopup']) && $this->easy_map['openPopup']==""){
			$openPopup = 0;
		}
		
		?>
		<script>
			document.addEventListener('DOMContentLoaded', function() {

					var marker = <?php echo esc_attr(($this->easy_map['marker']) ? 1 : 0); ?>;	
					var openPopup = <?php echo esc_attr($openPopup); ?>;	
					var zoomControl = <?php echo esc_attr(($this->easy_map['zoomControl']) ? 1 : 0); ?>;
					var fullScreen = <?php echo esc_attr(($this->easy_map['fullScreen']) ? 1 : 0); ?>;
					
					var easy_map = L.map('<?php echo esc_attr($this->map); ?>',{zoomControl: zoomControl , scrollWheelZoom: <?php echo esc_attr(($this->easy_map['scrollWheelZoom']) ? 1 : 0); ?> }).setView([<?php echo esc_attr($this->easy_map['lat']); ?>, <?php echo esc_attr($this->easy_map['lon']); ?>], <?php echo esc_attr($this->easy_map['zoom']); ?>);
					var tilelayer = '<?php echo esc_attr(isset($this->easy_map['tilelayer']) ? $this->easy_map['tilelayer'] : 'osm'); ?>';
					
					if(zoomControl && !fullScreen){
						L.control.zoom({
						position: '<?php echo esc_attr(($this->easy_map['zoomControlPosition']) ? $this->easy_map['zoomControlPosition'] : 'topleft'); ?>'
						}).addTo(easy_map);

						easy_map.zoomControl.remove();
					}

					if(fullScreen){
						easy_map.addControl(L.control.fullscreen());
					}

					if (tilelayer == 'bing') {
						L.tileLayer.bing({
							bingMapsKey: '<?php echo esc_attr(isset($this->easy_map['bingMapKey']) ? sanitize_text_field($this->easy_map['bingMapKey']) : ''); ?>',
							imagerySet: 'Road', // For road maps
						}).addTo(easy_map);
					} else if (tilelayer == 'google') {
						L.gridLayer.googleMutant({
							id: 'roads',
							type: 'roadmap'
						}).addTo(easy_map);
					} else {
						L.tileLayer('https://tile.openstreetmap.org/{z}/{x}/{y}.png', {
							attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors'
						}).addTo(easy_map);
					}

					if(marker){
						
						var locations = [
							[<?php echo esc_attr($this->easy_map['lat'])?>,<?php echo esc_attr($this->easy_map['lon']); ?>,<?php echo wp_json_encode( $this->easy_map['popup']); ?>]
						];

						for (var i = 0; i < locations.length; i++) {
							if (locations[i][2] == 0) {
								L.marker([locations[i][0], locations[i][1]]).addTo(easy_map);
							} else {
								if(openPopup==1)
									L.marker([locations[i][0], locations[i][1]]).addTo(easy_map).bindPopup(locations[i][2]).openPopup();
								else
									L.marker([locations[i][0], locations[i][1]]).addTo(easy_map).bindPopup(locations[i][2]);
							}
						}
					}

					easy_map_set(easy_map);
			});
		
		</script>
	<?php 
    }

	public	function easy_map_marker_render($atts,$content,$tag)
	{
		
		if (!empty($atts)) {

			$this->easy_map_marker=[];

			if (isset($atts['id']) && $atts['id'] != "" && is_numeric($atts['id'])) {

				$easy_map_marker_setting = (array) $this->get_location($atts['id']);

			}else{

				$lat    = isset($atts['lat']) ? sanitize_text_field($atts['lat']) : 0;
				$lon = isset($atts['lon']) ? sanitize_textarea_field($atts['lon']) : 0;
				$popup   = isset($atts['popup']) ? sanitize_text_field($atts['popup']) : 0;
				$openPopup   = isset($atts['openPopup']) ? sanitize_text_field($atts['openPopup']) : 1;

				$setting = [
					'lat' => $lat,
					'lon' => $lon,
					'popup' => $popup,
					'open_popup' => $openPopup,
				];
				$easy_map_marker_setting = $setting;
			}
			if(!empty($this->easy_map)){
				ob_start();
				$this->easy_map_marker_dom_render( $easy_map_marker_setting, $tag );
				return ob_get_clean();
			}
		}
	}

	/**
     * Fetch a single contact from the DB
     *
     * @param  int $id
     *
     * @return object
    */
    public function get_location( $id ) {
        global $wpdb;
        $db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;
        return $wpdb->get_row(
            $wpdb->prepare( "SELECT * FROM {$db_prefix}_locations WHERE id = %d", $id )
        );
    }

	private function easy_map_marker_dom_render( $easy_map_marker_setting , $short_code ){
		
		$this->easy_map_marker[]=$easy_map_marker_setting;
		?>
		<script>
			
			document.addEventListener('DOMContentLoaded', function() {
				
				var short_code = '<?php echo esc_attr($short_code); ?>';
				if(short_code=='easy-map-marker'){
					var existingMap = easy_map_get();
					
					<?php foreach ($this->easy_map_marker as $marker) { 
						if(!empty($marker)){
						?>
						if ('<?php echo wp_json_encode($marker['popup']) ?>' == '""') {
							L.marker([<?php echo esc_attr($marker['lat']) ?>, <?php echo esc_attr( $marker['lon'] )?>]).addTo(existingMap);
						} else {
							if ('<?php echo esc_attr($marker['open_popup']) ?>' == 1) {
								L.marker([<?php echo esc_attr($marker['lat']) ?>, <?php echo esc_attr( $marker['lon'] )?>])
								.addTo(existingMap)
								.bindPopup(<?php echo wp_json_encode($marker['popup']) ?>)
								.openPopup();
							}else{
								L.marker([<?php echo esc_attr($marker['lat']) ?>, <?php echo esc_attr( $marker['lon'] )?>])
								.addTo(existingMap)
								.bindPopup(<?php echo wp_json_encode($marker['popup']) ?>);
							}
						}
					<?php } }?>

				}
			});
		
		</script>
	<?php 
    }

	public	function easy_map_polyline_render( $atts , $content, $tag )
	{
		
		if (!empty($atts)) {
			$latlons    = isset($atts['latlons']) ? sanitize_text_field($atts['latlons']) : 0;
			$setting = [
				'latlons' => $latlons,
			];

			$easy_map_polyline_setting = $setting;
			ob_start();
			$this->easy_map_polyline_dom_render( $easy_map_polyline_setting, $tag );
			return ob_get_clean();
		}
	}

	private function easy_map_polyline_dom_render( $easy_map_polyline_setting , $short_code ){
		
		$this->easy_map_polyline=$easy_map_polyline_setting;
		
		?>
		<script>
			
			document.addEventListener('DOMContentLoaded', function() {
				
				var short_code = '<?php echo esc_attr($short_code); ?>';
				if(short_code=='easy-map-polyline'){
					var existingMap = easy_map_get();
					var latlons = '<?php echo esc_attr($this->easy_map_polyline['latlons']); ?>';
					var latlngs = latlons.split("-");
					var latlon = [];
					for (var i = 0; i < latlngs.length; i++) {
						latlon[i] = latlngs[i].split(",");
					}
					L.polyline(latlon, {color: 'red'}).addTo(existingMap);
				}
			});
		
		</script>
	<?php 
    }

	/**
     * Fetch a single contact from the DB
     *
     * @param  int $id
     *
     * @return object
     */
    public function get_drawing( $id ) {
        global $wpdb;
        $db_prefix = $wpdb->prefix.EASY_MAP_DB_PREFIX;
        return $wpdb->get_row(
            $wpdb->prepare( "SELECT * FROM {$db_prefix}_drawing WHERE id = %d", $id )
        );
    }

	public	function easy_map_drawing_render( $atts , $content, $tag )
	{
		
		if (!empty($atts)) {
			$id    = isset($atts['id']) ? sanitize_text_field($atts['id']) : 0;
			$easy_map_drawing_setting = (array) $this->get_drawing($id);
			
			if(!empty($easy_map_drawing_setting) && (!empty($this->easy_map))){
				ob_start();
				$this->easy_map_drawing_dom_render( $easy_map_drawing_setting, $tag );
				return ob_get_clean();
			}
		}
	}

	private function easy_map_drawing_dom_render( $easy_map_drawing_setting , $short_code ){
		
		?>
		<script>
			
			document.addEventListener('DOMContentLoaded', function() {
				
				var short_code = '<?php echo esc_attr($short_code); ?>';
				var existingMap = easy_map_get();
				if(short_code=='easy-map-drawing'){
					var polyline = '<?php echo esc_attr($easy_map_drawing_setting['polyline']); ?>';
					var polygon = '<?php echo esc_attr($easy_map_drawing_setting['polygon']); ?>';
					var marker = '<?php echo wp_json_encode($easy_map_drawing_setting['marker']); ?>';
					if(polyline){
						var polylines = JSON.parse(polyline);
						L.polyline(polylines, {color: 'red'}).addTo(existingMap);
					}
					if(polygon){
						var polygons = JSON.parse(polygon);
						L.polygon(polygons, {color: 'purple'}).addTo(existingMap);
					}
					if(marker!='""'){
						let fixedJson1 = marker.slice(1, -1); 
						var fixedJson2 = fixedJson1.replace(/\\/g, ""); // Remove backslashes
						var markers = JSON.parse(fixedJson2);
						for (let i in markers) {
							if(markers[i][2])
								L.marker([markers[i][0], markers[i][1]]).addTo(existingMap).bindPopup(markers[i][2]);
							else
								L.marker([markers[i][0], markers[i][1]]).addTo(existingMap);
						}
					}
				}
			});
		
		</script>
	<?php 
    }
}
